/* Generated by makegdkalias.pl */

#ifndef DISABLE_VISIBILITY

#include <glib.h>

#ifdef G_HAVE_GNUC_VISIBILITY

#define IN_FILE(x) 1
#define IN_HEADER defined

#if IN_HEADER(__GDK_EVENTS_H__)
#if IN_FILE(__GDK_EVENTS_X11_C__)
extern __typeof (gdk_add_client_message_filter) IA__gdk_add_client_message_filter __attribute((visibility("hidden")));
#define gdk_add_client_message_filter IA__gdk_add_client_message_filter

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_event_get_graphics_expose) IA__gdk_event_get_graphics_expose __attribute((visibility("hidden")));
#define gdk_event_get_graphics_expose IA__gdk_event_get_graphics_expose

#endif
extern __typeof (gdk_events_pending) IA__gdk_events_pending __attribute((visibility("hidden")));
#define gdk_events_pending IA__gdk_events_pending

#endif
#endif
#if IN_HEADER(__GDK_TEST_UTILS_H__)
#if IN_FILE(__GDK_TEST_UTILS_X11_C__)
extern __typeof (gdk_test_simulate_button) IA__gdk_test_simulate_button __attribute((visibility("hidden")));
#define gdk_test_simulate_button IA__gdk_test_simulate_button

extern __typeof (gdk_test_simulate_key) IA__gdk_test_simulate_key __attribute((visibility("hidden")));
#define gdk_test_simulate_key IA__gdk_test_simulate_key

extern __typeof (gdk_test_render_sync) IA__gdk_test_render_sync __attribute((visibility("hidden")));
#define gdk_test_render_sync IA__gdk_test_render_sync

#endif
#endif
#if IN_HEADER(__GDK_EVENTS_H__)
#if IN_FILE(__GDK_EVENTS_C__)
extern __typeof (gdk_event_copy) IA__gdk_event_copy __attribute((visibility("hidden")));
#define gdk_event_copy IA__gdk_event_copy

extern __typeof (gdk_event_free) IA__gdk_event_free __attribute((visibility("hidden")));
#define gdk_event_free IA__gdk_event_free

extern __typeof (gdk_event_get) IA__gdk_event_get __attribute((visibility("hidden")));
#define gdk_event_get IA__gdk_event_get

extern __typeof (gdk_event_get_axis) IA__gdk_event_get_axis __attribute((visibility("hidden")));
#define gdk_event_get_axis IA__gdk_event_get_axis

extern __typeof (gdk_event_get_coords) IA__gdk_event_get_coords __attribute((visibility("hidden")));
#define gdk_event_get_coords IA__gdk_event_get_coords

extern __typeof (gdk_event_get_root_coords) IA__gdk_event_get_root_coords __attribute((visibility("hidden")));
#define gdk_event_get_root_coords IA__gdk_event_get_root_coords

extern __typeof (gdk_event_get_screen) IA__gdk_event_get_screen __attribute((visibility("hidden")));
#define gdk_event_get_screen IA__gdk_event_get_screen

extern __typeof (gdk_event_get_state) IA__gdk_event_get_state __attribute((visibility("hidden")));
#define gdk_event_get_state IA__gdk_event_get_state

extern __typeof (gdk_event_get_time) IA__gdk_event_get_time __attribute((visibility("hidden")));
#define gdk_event_get_time IA__gdk_event_get_time

extern __typeof (gdk_event_get_type) IA__gdk_event_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_event_get_type IA__gdk_event_get_type

extern __typeof (gdk_event_handler_set) IA__gdk_event_handler_set __attribute((visibility("hidden")));
#define gdk_event_handler_set IA__gdk_event_handler_set

extern __typeof (gdk_event_new) IA__gdk_event_new __attribute((visibility("hidden")));
#define gdk_event_new IA__gdk_event_new

extern __typeof (gdk_event_peek) IA__gdk_event_peek __attribute((visibility("hidden")));
#define gdk_event_peek IA__gdk_event_peek

extern __typeof (gdk_event_put) IA__gdk_event_put __attribute((visibility("hidden")));
#define gdk_event_put IA__gdk_event_put

extern __typeof (gdk_event_request_motions) IA__gdk_event_request_motions __attribute((visibility("hidden")));
#define gdk_event_request_motions IA__gdk_event_request_motions

extern __typeof (gdk_event_set_screen) IA__gdk_event_set_screen __attribute((visibility("hidden")));
#define gdk_event_set_screen IA__gdk_event_set_screen

extern __typeof (gdk_get_show_events) IA__gdk_get_show_events __attribute((visibility("hidden")));
#define gdk_get_show_events IA__gdk_get_show_events

extern __typeof (gdk_set_show_events) IA__gdk_set_show_events __attribute((visibility("hidden")));
#define gdk_set_show_events IA__gdk_set_show_events

extern __typeof (gdk_setting_get) IA__gdk_setting_get __attribute((visibility("hidden")));
#define gdk_setting_get IA__gdk_setting_get

#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_MAIN_X11_C__)
extern __typeof (gdk_error_trap_pop) IA__gdk_error_trap_pop __attribute((visibility("hidden")));
#define gdk_error_trap_pop IA__gdk_error_trap_pop

extern __typeof (gdk_error_trap_push) IA__gdk_error_trap_push __attribute((visibility("hidden")));
#define gdk_error_trap_push IA__gdk_error_trap_push

extern __typeof (gdk_get_display) IA__gdk_get_display __attribute((visibility("hidden")));
#define gdk_get_display IA__gdk_get_display

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_get_use_xshm) IA__gdk_get_use_xshm __attribute((visibility("hidden")));
#define gdk_get_use_xshm IA__gdk_get_use_xshm

extern __typeof (gdk_set_use_xshm) IA__gdk_set_use_xshm __attribute((visibility("hidden")));
#define gdk_set_use_xshm IA__gdk_set_use_xshm

#endif
extern __typeof (gdk_keyboard_grab) IA__gdk_keyboard_grab __attribute((visibility("hidden")));
#define gdk_keyboard_grab IA__gdk_keyboard_grab

#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_DISPLAY_C__)
extern __typeof (gdk_beep) IA__gdk_beep __attribute((visibility("hidden")));
#define gdk_beep IA__gdk_beep

extern __typeof (gdk_set_pointer_hooks) IA__gdk_set_pointer_hooks __attribute((visibility("hidden")));
#define gdk_set_pointer_hooks IA__gdk_set_pointer_hooks

extern __typeof (gdk_keyboard_ungrab) IA__gdk_keyboard_ungrab __attribute((visibility("hidden")));
#define gdk_keyboard_ungrab IA__gdk_keyboard_ungrab

extern __typeof (gdk_pointer_is_grabbed) IA__gdk_pointer_is_grabbed __attribute((visibility("hidden")));
#define gdk_pointer_is_grabbed IA__gdk_pointer_is_grabbed

extern __typeof (gdk_pointer_ungrab) IA__gdk_pointer_ungrab __attribute((visibility("hidden")));
#define gdk_pointer_ungrab IA__gdk_pointer_ungrab

extern __typeof (gdk_event_send_client_message) IA__gdk_event_send_client_message __attribute((visibility("hidden")));
#define gdk_event_send_client_message IA__gdk_event_send_client_message

extern __typeof (gdk_event_send_clientmessage_toall) IA__gdk_event_send_clientmessage_toall __attribute((visibility("hidden")));
#define gdk_event_send_clientmessage_toall IA__gdk_event_send_clientmessage_toall

extern __typeof (gdk_keyboard_grab_info_libgtk_only) IA__gdk_keyboard_grab_info_libgtk_only __attribute((visibility("hidden")));
#define gdk_keyboard_grab_info_libgtk_only IA__gdk_keyboard_grab_info_libgtk_only

extern __typeof (gdk_pointer_grab_info_libgtk_only) IA__gdk_pointer_grab_info_libgtk_only __attribute((visibility("hidden")));
#define gdk_pointer_grab_info_libgtk_only IA__gdk_pointer_grab_info_libgtk_only

extern __typeof (gdk_display_pointer_is_grabbed) IA__gdk_display_pointer_is_grabbed __attribute((visibility("hidden")));
#define gdk_display_pointer_is_grabbed IA__gdk_display_pointer_is_grabbed

#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_IM_X11_C__)
#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_mbstowcs) IA__gdk_mbstowcs __attribute((visibility("hidden")));
#define gdk_mbstowcs IA__gdk_mbstowcs

extern __typeof (gdk_wcstombs) IA__gdk_wcstombs __attribute((visibility("hidden")));
#define gdk_wcstombs IA__gdk_wcstombs

extern __typeof (gdk_set_locale) IA__gdk_set_locale __attribute((visibility("hidden")));
#define gdk_set_locale IA__gdk_set_locale

#endif
#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_EVENTS_X11_C__)
extern __typeof (gdk_event_send_client_message_for_display) IA__gdk_event_send_client_message_for_display __attribute((visibility("hidden")));
#define gdk_event_send_client_message_for_display IA__gdk_event_send_client_message_for_display

extern __typeof (gdk_flush) IA__gdk_flush __attribute((visibility("hidden")));
#define gdk_flush IA__gdk_flush

#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_DISPLAY_X11_C__)
extern __typeof (gdk_notify_startup_complete) IA__gdk_notify_startup_complete __attribute((visibility("hidden")));
#define gdk_notify_startup_complete IA__gdk_notify_startup_complete

extern __typeof (gdk_notify_startup_complete_with_id) IA__gdk_notify_startup_complete_with_id __attribute((visibility("hidden")));
#define gdk_notify_startup_complete_with_id IA__gdk_notify_startup_complete_with_id

#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_RECTANGLE_C__)
extern __typeof (gdk_rectangle_get_type) IA__gdk_rectangle_get_type __attribute((visibility("hidden")));
#define gdk_rectangle_get_type IA__gdk_rectangle_get_type

extern __typeof (gdk_rectangle_intersect) IA__gdk_rectangle_intersect __attribute((visibility("hidden")));
#define gdk_rectangle_intersect IA__gdk_rectangle_intersect

extern __typeof (gdk_rectangle_union) IA__gdk_rectangle_union __attribute((visibility("hidden")));
#define gdk_rectangle_union IA__gdk_rectangle_union

#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_EVENTS_C__)
extern __typeof (gdk_set_double_click_time) IA__gdk_set_double_click_time __attribute((visibility("hidden")));
#define gdk_set_double_click_time IA__gdk_set_double_click_time

#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_C__)
extern __typeof (gdk_add_option_entries_libgtk_only) IA__gdk_add_option_entries_libgtk_only __attribute((visibility("hidden")));
#define gdk_add_option_entries_libgtk_only IA__gdk_add_option_entries_libgtk_only

extern __typeof (gdk_get_display_arg_name) IA__gdk_get_display_arg_name __attribute((visibility("hidden")));
#define gdk_get_display_arg_name IA__gdk_get_display_arg_name

extern __typeof (gdk_get_program_class) IA__gdk_get_program_class __attribute((visibility("hidden")));
#define gdk_get_program_class IA__gdk_get_program_class

extern __typeof (gdk_init) IA__gdk_init __attribute((visibility("hidden")));
#define gdk_init IA__gdk_init

extern __typeof (gdk_init_check) IA__gdk_init_check __attribute((visibility("hidden")));
#define gdk_init_check IA__gdk_init_check

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_exit) IA__gdk_exit __attribute((visibility("hidden")));
#define gdk_exit IA__gdk_exit

#endif
extern __typeof (gdk_pre_parse_libgtk_only) IA__gdk_pre_parse_libgtk_only __attribute((visibility("hidden")));
#define gdk_pre_parse_libgtk_only IA__gdk_pre_parse_libgtk_only

extern __typeof (gdk_parse_args) IA__gdk_parse_args __attribute((visibility("hidden")));
#define gdk_parse_args IA__gdk_parse_args

extern __typeof (gdk_set_program_class) IA__gdk_set_program_class __attribute((visibility("hidden")));
#define gdk_set_program_class IA__gdk_set_program_class

extern __typeof (gdk_threads_enter) IA__gdk_threads_enter __attribute((visibility("hidden")));
#define gdk_threads_enter IA__gdk_threads_enter

extern __typeof (gdk_threads_init) IA__gdk_threads_init __attribute((visibility("hidden")));
#define gdk_threads_init IA__gdk_threads_init

extern __typeof (gdk_threads_leave) IA__gdk_threads_leave __attribute((visibility("hidden")));
#define gdk_threads_leave IA__gdk_threads_leave

extern __typeof (gdk_threads_set_lock_functions) IA__gdk_threads_set_lock_functions __attribute((visibility("hidden")));
#define gdk_threads_set_lock_functions IA__gdk_threads_set_lock_functions

extern __typeof (gdk_threads_add_idle) IA__gdk_threads_add_idle __attribute((visibility("hidden")));
#define gdk_threads_add_idle IA__gdk_threads_add_idle

extern __typeof (gdk_threads_add_idle_full) IA__gdk_threads_add_idle_full __attribute((visibility("hidden")));
#define gdk_threads_add_idle_full IA__gdk_threads_add_idle_full

extern __typeof (gdk_threads_add_timeout) IA__gdk_threads_add_timeout __attribute((visibility("hidden")));
#define gdk_threads_add_timeout IA__gdk_threads_add_timeout

extern __typeof (gdk_threads_add_timeout_full) IA__gdk_threads_add_timeout_full __attribute((visibility("hidden")));
#define gdk_threads_add_timeout_full IA__gdk_threads_add_timeout_full

extern __typeof (gdk_threads_add_timeout_seconds) IA__gdk_threads_add_timeout_seconds __attribute((visibility("hidden")));
#define gdk_threads_add_timeout_seconds IA__gdk_threads_add_timeout_seconds

extern __typeof (gdk_threads_add_timeout_seconds_full) IA__gdk_threads_add_timeout_seconds_full __attribute((visibility("hidden")));
#define gdk_threads_add_timeout_seconds_full IA__gdk_threads_add_timeout_seconds_full

#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_EVENTS_C__)
#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_input_add) IA__gdk_input_add __attribute((visibility("hidden")));
#define gdk_input_add IA__gdk_input_add

extern __typeof (gdk_input_remove) IA__gdk_input_remove __attribute((visibility("hidden")));
#define gdk_input_remove IA__gdk_input_remove

extern __typeof (gdk_input_add_full) IA__gdk_input_add_full __attribute((visibility("hidden")));
#define gdk_input_add_full IA__gdk_input_add_full

#endif
#endif
#endif
#if IN_HEADER(__GDK_H__)
#if IN_FILE(__GDK_SCREEN_C__)
extern __typeof (gdk_screen_width) IA__gdk_screen_width __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_screen_width IA__gdk_screen_width

extern __typeof (gdk_screen_width_mm) IA__gdk_screen_width_mm __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_screen_width_mm IA__gdk_screen_width_mm

extern __typeof (gdk_screen_height) IA__gdk_screen_height __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_screen_height IA__gdk_screen_height

extern __typeof (gdk_screen_height_mm) IA__gdk_screen_height_mm __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_screen_height_mm IA__gdk_screen_height_mm

#endif
#endif
#if IN_HEADER(__GDK_PROPERTY_H__)
#if IN_FILE(__GDK_SELECTION_C__)
#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_string_to_compound_text) IA__gdk_string_to_compound_text __attribute((visibility("hidden")));
#define gdk_string_to_compound_text IA__gdk_string_to_compound_text

extern __typeof (gdk_text_property_to_text_list) IA__gdk_text_property_to_text_list __attribute((visibility("hidden")));
#define gdk_text_property_to_text_list IA__gdk_text_property_to_text_list

extern __typeof (gdk_text_property_to_utf8_list) IA__gdk_text_property_to_utf8_list __attribute((visibility("hidden")));
#define gdk_text_property_to_utf8_list IA__gdk_text_property_to_utf8_list

extern __typeof (gdk_utf8_to_compound_text) IA__gdk_utf8_to_compound_text __attribute((visibility("hidden")));
#define gdk_utf8_to_compound_text IA__gdk_utf8_to_compound_text

#endif
#endif
#endif
#if IN_HEADER(__GDK_PROPERTY_H__)
#if IN_FILE(__GDK_PROPERTY_X11_C__)
extern __typeof (gdk_atom_intern) IA__gdk_atom_intern __attribute((visibility("hidden")));
#define gdk_atom_intern IA__gdk_atom_intern

extern __typeof (gdk_atom_intern_static_string) IA__gdk_atom_intern_static_string __attribute((visibility("hidden")));
#define gdk_atom_intern_static_string IA__gdk_atom_intern_static_string

extern __typeof (gdk_atom_name) IA__gdk_atom_name __attribute((visibility("hidden")));
#define gdk_atom_name IA__gdk_atom_name

extern __typeof (gdk_property_change) IA__gdk_property_change __attribute((visibility("hidden")));
#define gdk_property_change IA__gdk_property_change

extern __typeof (gdk_property_delete) IA__gdk_property_delete __attribute((visibility("hidden")));
#define gdk_property_delete IA__gdk_property_delete

extern __typeof (gdk_property_get) IA__gdk_property_get __attribute((visibility("hidden")));
#define gdk_property_get IA__gdk_property_get

#endif
#endif
#if IN_HEADER(__GDK_PROPERTY_H__)
#if IN_FILE(__GDK_SELECTION_X11_C__)
#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_free_compound_text) IA__gdk_free_compound_text __attribute((visibility("hidden")));
#define gdk_free_compound_text IA__gdk_free_compound_text

extern __typeof (gdk_free_text_list) IA__gdk_free_text_list __attribute((visibility("hidden")));
#define gdk_free_text_list IA__gdk_free_text_list

extern __typeof (gdk_string_to_compound_text_for_display) IA__gdk_string_to_compound_text_for_display __attribute((visibility("hidden")));
#define gdk_string_to_compound_text_for_display IA__gdk_string_to_compound_text_for_display

extern __typeof (gdk_text_property_to_text_list_for_display) IA__gdk_text_property_to_text_list_for_display __attribute((visibility("hidden")));
#define gdk_text_property_to_text_list_for_display IA__gdk_text_property_to_text_list_for_display

extern __typeof (gdk_utf8_to_compound_text_for_display) IA__gdk_utf8_to_compound_text_for_display __attribute((visibility("hidden")));
#define gdk_utf8_to_compound_text_for_display IA__gdk_utf8_to_compound_text_for_display

#endif
extern __typeof (gdk_text_property_to_utf8_list_for_display) IA__gdk_text_property_to_utf8_list_for_display __attribute((visibility("hidden")));
#define gdk_text_property_to_utf8_list_for_display IA__gdk_text_property_to_utf8_list_for_display

extern __typeof (gdk_utf8_to_string_target) IA__gdk_utf8_to_string_target __attribute((visibility("hidden")));
#define gdk_utf8_to_string_target IA__gdk_utf8_to_string_target

#endif
#endif
#ifdef GDK_WINDOWING_X11
#if IN_HEADER(__GDK_X_H__)
#if IN_FILE(__GDK_SELECTION_X11_C__)
extern __typeof (gdk_x11_display_string_to_compound_text) IA__gdk_x11_display_string_to_compound_text __attribute((visibility("hidden")));
#define gdk_x11_display_string_to_compound_text IA__gdk_x11_display_string_to_compound_text

extern __typeof (gdk_x11_display_text_property_to_text_list) IA__gdk_x11_display_text_property_to_text_list __attribute((visibility("hidden")));
#define gdk_x11_display_text_property_to_text_list IA__gdk_x11_display_text_property_to_text_list

extern __typeof (gdk_x11_display_utf8_to_compound_text) IA__gdk_x11_display_utf8_to_compound_text __attribute((visibility("hidden")));
#define gdk_x11_display_utf8_to_compound_text IA__gdk_x11_display_utf8_to_compound_text

extern __typeof (gdk_x11_free_compound_text) IA__gdk_x11_free_compound_text __attribute((visibility("hidden")));
#define gdk_x11_free_compound_text IA__gdk_x11_free_compound_text

extern __typeof (gdk_x11_free_text_list) IA__gdk_x11_free_text_list __attribute((visibility("hidden")));
#define gdk_x11_free_text_list IA__gdk_x11_free_text_list

#endif
#endif
#endif
#if IN_HEADER(__GDK_ENUM_TYPES_H__)
#if IN_FILE(__GDK_ENUM_TYPES_C__)
extern __typeof (gdk_rgb_dither_get_type) IA__gdk_rgb_dither_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_rgb_dither_get_type IA__gdk_rgb_dither_get_type

extern __typeof (gdk_drag_protocol_get_type) IA__gdk_drag_protocol_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_drag_protocol_get_type IA__gdk_drag_protocol_get_type

extern __typeof (gdk_input_source_get_type) IA__gdk_input_source_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_input_source_get_type IA__gdk_input_source_get_type

extern __typeof (gdk_input_condition_get_type) IA__gdk_input_condition_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_input_condition_get_type IA__gdk_input_condition_get_type

extern __typeof (gdk_input_mode_get_type) IA__gdk_input_mode_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_input_mode_get_type IA__gdk_input_mode_get_type

extern __typeof (gdk_axis_use_get_type) IA__gdk_axis_use_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_axis_use_get_type IA__gdk_axis_use_get_type

extern __typeof (gdk_byte_order_get_type) IA__gdk_byte_order_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_byte_order_get_type IA__gdk_byte_order_get_type

extern __typeof (gdk_cap_style_get_type) IA__gdk_cap_style_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_cap_style_get_type IA__gdk_cap_style_get_type

extern __typeof (gdk_crossing_mode_get_type) IA__gdk_crossing_mode_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_crossing_mode_get_type IA__gdk_crossing_mode_get_type

extern __typeof (gdk_extension_mode_get_type) IA__gdk_extension_mode_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_extension_mode_get_type IA__gdk_extension_mode_get_type

extern __typeof (gdk_event_mask_get_type) IA__gdk_event_mask_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_event_mask_get_type IA__gdk_event_mask_get_type

extern __typeof (gdk_event_type_get_type) IA__gdk_event_type_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_event_type_get_type IA__gdk_event_type_get_type

extern __typeof (gdk_fill_get_type) IA__gdk_fill_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_fill_get_type IA__gdk_fill_get_type

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_fill_rule_get_type) IA__gdk_fill_rule_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_fill_rule_get_type IA__gdk_fill_rule_get_type

#endif
extern __typeof (gdk_filter_return_get_type) IA__gdk_filter_return_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_filter_return_get_type IA__gdk_filter_return_get_type

extern __typeof (gdk_function_get_type) IA__gdk_function_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_function_get_type IA__gdk_function_get_type

extern __typeof (gdk_grab_status_get_type) IA__gdk_grab_status_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_grab_status_get_type IA__gdk_grab_status_get_type

extern __typeof (gdk_gravity_get_type) IA__gdk_gravity_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_gravity_get_type IA__gdk_gravity_get_type

extern __typeof (gdk_join_style_get_type) IA__gdk_join_style_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_join_style_get_type IA__gdk_join_style_get_type

extern __typeof (gdk_line_style_get_type) IA__gdk_line_style_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_line_style_get_type IA__gdk_line_style_get_type

extern __typeof (gdk_modifier_type_get_type) IA__gdk_modifier_type_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_modifier_type_get_type IA__gdk_modifier_type_get_type

extern __typeof (gdk_notify_type_get_type) IA__gdk_notify_type_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_notify_type_get_type IA__gdk_notify_type_get_type

extern __typeof (gdk_overlap_type_get_type) IA__gdk_overlap_type_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_overlap_type_get_type IA__gdk_overlap_type_get_type

extern __typeof (gdk_owner_change_get_type) IA__gdk_owner_change_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_owner_change_get_type IA__gdk_owner_change_get_type

extern __typeof (gdk_property_state_get_type) IA__gdk_property_state_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_property_state_get_type IA__gdk_property_state_get_type

extern __typeof (gdk_prop_mode_get_type) IA__gdk_prop_mode_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_prop_mode_get_type IA__gdk_prop_mode_get_type

extern __typeof (gdk_scroll_direction_get_type) IA__gdk_scroll_direction_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_scroll_direction_get_type IA__gdk_scroll_direction_get_type

extern __typeof (gdk_setting_action_get_type) IA__gdk_setting_action_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_setting_action_get_type IA__gdk_setting_action_get_type

extern __typeof (gdk_status_get_type) IA__gdk_status_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_status_get_type IA__gdk_status_get_type

extern __typeof (gdk_subwindow_mode_get_type) IA__gdk_subwindow_mode_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_subwindow_mode_get_type IA__gdk_subwindow_mode_get_type

extern __typeof (gdk_visibility_state_get_type) IA__gdk_visibility_state_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_visibility_state_get_type IA__gdk_visibility_state_get_type

extern __typeof (gdk_wm_decoration_get_type) IA__gdk_wm_decoration_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_wm_decoration_get_type IA__gdk_wm_decoration_get_type

extern __typeof (gdk_wm_function_get_type) IA__gdk_wm_function_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_wm_function_get_type IA__gdk_wm_function_get_type

extern __typeof (gdk_font_type_get_type) IA__gdk_font_type_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_font_type_get_type IA__gdk_font_type_get_type

extern __typeof (gdk_cursor_type_get_type) IA__gdk_cursor_type_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_cursor_type_get_type IA__gdk_cursor_type_get_type

extern __typeof (gdk_drag_action_get_type) IA__gdk_drag_action_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_drag_action_get_type IA__gdk_drag_action_get_type

extern __typeof (gdk_gc_values_mask_get_type) IA__gdk_gc_values_mask_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_gc_values_mask_get_type IA__gdk_gc_values_mask_get_type

extern __typeof (gdk_window_attributes_type_get_type) IA__gdk_window_attributes_type_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_window_attributes_type_get_type IA__gdk_window_attributes_type_get_type

extern __typeof (gdk_window_class_get_type) IA__gdk_window_class_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_window_class_get_type IA__gdk_window_class_get_type

extern __typeof (gdk_window_edge_get_type) IA__gdk_window_edge_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_window_edge_get_type IA__gdk_window_edge_get_type

extern __typeof (gdk_window_hints_get_type) IA__gdk_window_hints_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_window_hints_get_type IA__gdk_window_hints_get_type

extern __typeof (gdk_window_state_get_type) IA__gdk_window_state_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_window_state_get_type IA__gdk_window_state_get_type

extern __typeof (gdk_window_type_get_type) IA__gdk_window_type_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_window_type_get_type IA__gdk_window_type_get_type

extern __typeof (gdk_window_type_hint_get_type) IA__gdk_window_type_hint_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_window_type_hint_get_type IA__gdk_window_type_hint_get_type

extern __typeof (gdk_image_type_get_type) IA__gdk_image_type_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_image_type_get_type IA__gdk_image_type_get_type

extern __typeof (gdk_visual_type_get_type) IA__gdk_visual_type_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_visual_type_get_type IA__gdk_visual_type_get_type

#endif
#endif
#if IN_HEADER(__GDK_FONT_H__)
#if IN_FILE(__GDK_FONT_C__)
#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_font_from_description) IA__gdk_font_from_description __attribute((visibility("hidden")));
#define gdk_font_from_description IA__gdk_font_from_description

#endif
extern __typeof (gdk_font_get_type) IA__gdk_font_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_font_get_type IA__gdk_font_get_type

extern __typeof (gdk_font_ref) IA__gdk_font_ref __attribute((visibility("hidden")));
#define gdk_font_ref IA__gdk_font_ref

extern __typeof (gdk_font_unref) IA__gdk_font_unref __attribute((visibility("hidden")));
#define gdk_font_unref IA__gdk_font_unref

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_font_load) IA__gdk_font_load __attribute((visibility("hidden")));
#define gdk_font_load IA__gdk_font_load

extern __typeof (gdk_string_width) IA__gdk_string_width __attribute((visibility("hidden")));
#define gdk_string_width IA__gdk_string_width

extern __typeof (gdk_char_width) IA__gdk_char_width __attribute((visibility("hidden")));
#define gdk_char_width IA__gdk_char_width

extern __typeof (gdk_char_width_wc) IA__gdk_char_width_wc __attribute((visibility("hidden")));
#define gdk_char_width_wc IA__gdk_char_width_wc

extern __typeof (gdk_string_measure) IA__gdk_string_measure __attribute((visibility("hidden")));
#define gdk_string_measure IA__gdk_string_measure

extern __typeof (gdk_text_measure) IA__gdk_text_measure __attribute((visibility("hidden")));
#define gdk_text_measure IA__gdk_text_measure

extern __typeof (gdk_char_measure) IA__gdk_char_measure __attribute((visibility("hidden")));
#define gdk_char_measure IA__gdk_char_measure

extern __typeof (gdk_string_height) IA__gdk_string_height __attribute((visibility("hidden")));
#define gdk_string_height IA__gdk_string_height

extern __typeof (gdk_text_height) IA__gdk_text_height __attribute((visibility("hidden")));
#define gdk_text_height IA__gdk_text_height

extern __typeof (gdk_char_height) IA__gdk_char_height __attribute((visibility("hidden")));
#define gdk_char_height IA__gdk_char_height

extern __typeof (gdk_string_extents) IA__gdk_string_extents __attribute((visibility("hidden")));
#define gdk_string_extents IA__gdk_string_extents

#endif
#endif
#endif
#if IN_HEADER(__GDK_FONT_H__)
#if IN_FILE(__GDK_FONT_X11_C__)
#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_text_extents) IA__gdk_text_extents __attribute((visibility("hidden")));
#define gdk_text_extents IA__gdk_text_extents

extern __typeof (gdk_text_extents_wc) IA__gdk_text_extents_wc __attribute((visibility("hidden")));
#define gdk_text_extents_wc IA__gdk_text_extents_wc

extern __typeof (gdk_text_width) IA__gdk_text_width __attribute((visibility("hidden")));
#define gdk_text_width IA__gdk_text_width

extern __typeof (gdk_text_width_wc) IA__gdk_text_width_wc __attribute((visibility("hidden")));
#define gdk_text_width_wc IA__gdk_text_width_wc

extern __typeof (gdk_font_get_display) IA__gdk_font_get_display __attribute((visibility("hidden")));
#define gdk_font_get_display IA__gdk_font_get_display

extern __typeof (gdk_fontset_load) IA__gdk_fontset_load __attribute((visibility("hidden")));
#define gdk_fontset_load IA__gdk_fontset_load

#endif
extern __typeof (gdk_font_id) IA__gdk_font_id __attribute((visibility("hidden")));
#define gdk_font_id IA__gdk_font_id

extern __typeof (gdk_font_equal) IA__gdk_font_equal __attribute((visibility("hidden")));
#define gdk_font_equal IA__gdk_font_equal

extern __typeof (gdk_font_load_for_display) IA__gdk_font_load_for_display __attribute((visibility("hidden")));
#define gdk_font_load_for_display IA__gdk_font_load_for_display

extern __typeof (gdk_font_from_description_for_display) IA__gdk_font_from_description_for_display __attribute((visibility("hidden")));
#define gdk_font_from_description_for_display IA__gdk_font_from_description_for_display

extern __typeof (gdk_fontset_load_for_display) IA__gdk_fontset_load_for_display __attribute((visibility("hidden")));
#define gdk_fontset_load_for_display IA__gdk_fontset_load_for_display

#endif
#endif
#if IN_HEADER(__GDK_CAIRO_H__)
#if IN_FILE(__GDK_CAIRO_C__)
extern __typeof (gdk_cairo_create) IA__gdk_cairo_create __attribute((visibility("hidden")));
#define gdk_cairo_create IA__gdk_cairo_create

extern __typeof (gdk_cairo_reset_clip) IA__gdk_cairo_reset_clip __attribute((visibility("hidden")));
#define gdk_cairo_reset_clip IA__gdk_cairo_reset_clip

extern __typeof (gdk_cairo_set_source_color) IA__gdk_cairo_set_source_color __attribute((visibility("hidden")));
#define gdk_cairo_set_source_color IA__gdk_cairo_set_source_color

extern __typeof (gdk_cairo_set_source_pixbuf) IA__gdk_cairo_set_source_pixbuf __attribute((visibility("hidden")));
#define gdk_cairo_set_source_pixbuf IA__gdk_cairo_set_source_pixbuf

extern __typeof (gdk_cairo_set_source_pixmap) IA__gdk_cairo_set_source_pixmap __attribute((visibility("hidden")));
#define gdk_cairo_set_source_pixmap IA__gdk_cairo_set_source_pixmap

extern __typeof (gdk_cairo_set_source_window) IA__gdk_cairo_set_source_window __attribute((visibility("hidden")));
#define gdk_cairo_set_source_window IA__gdk_cairo_set_source_window

extern __typeof (gdk_cairo_rectangle) IA__gdk_cairo_rectangle __attribute((visibility("hidden")));
#define gdk_cairo_rectangle IA__gdk_cairo_rectangle

extern __typeof (gdk_cairo_region) IA__gdk_cairo_region __attribute((visibility("hidden")));
#define gdk_cairo_region IA__gdk_cairo_region

#endif
#endif
#if IN_HEADER(__GDK_COLOR_H__)
#if IN_FILE(__GDK_COLOR_C__)
#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_colors_store) IA__gdk_colors_store __attribute((visibility("hidden")));
#define gdk_colors_store IA__gdk_colors_store

extern __typeof (gdk_color_white) IA__gdk_color_white __attribute((visibility("hidden")));
#define gdk_color_white IA__gdk_color_white

extern __typeof (gdk_color_black) IA__gdk_color_black __attribute((visibility("hidden")));
#define gdk_color_black IA__gdk_color_black

extern __typeof (gdk_color_alloc) IA__gdk_color_alloc __attribute((visibility("hidden")));
#define gdk_color_alloc IA__gdk_color_alloc

#endif
extern __typeof (gdk_color_copy) IA__gdk_color_copy __attribute((visibility("hidden")));
#define gdk_color_copy IA__gdk_color_copy

extern __typeof (gdk_color_equal) IA__gdk_color_equal __attribute((visibility("hidden")));
#define gdk_color_equal IA__gdk_color_equal

extern __typeof (gdk_color_free) IA__gdk_color_free __attribute((visibility("hidden")));
#define gdk_color_free IA__gdk_color_free

extern __typeof (gdk_color_get_type) IA__gdk_color_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_color_get_type IA__gdk_color_get_type

extern __typeof (gdk_color_hash) IA__gdk_color_hash __attribute((visibility("hidden")));
#define gdk_color_hash IA__gdk_color_hash

extern __typeof (gdk_colormap_alloc_color) IA__gdk_colormap_alloc_color __attribute((visibility("hidden")));
#define gdk_colormap_alloc_color IA__gdk_colormap_alloc_color

extern __typeof (gdk_colormap_get_system) IA__gdk_colormap_get_system __attribute((visibility("hidden")));
#define gdk_colormap_get_system IA__gdk_colormap_get_system

extern __typeof (gdk_colormap_get_visual) IA__gdk_colormap_get_visual __attribute((visibility("hidden")));
#define gdk_colormap_get_visual IA__gdk_colormap_get_visual

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_colormap_ref) IA__gdk_colormap_ref __attribute((visibility("hidden")));
#define gdk_colormap_ref IA__gdk_colormap_ref

extern __typeof (gdk_colormap_unref) IA__gdk_colormap_unref __attribute((visibility("hidden")));
#define gdk_colormap_unref IA__gdk_colormap_unref

#endif
extern __typeof (gdk_color_parse) IA__gdk_color_parse __attribute((visibility("hidden")));
#define gdk_color_parse IA__gdk_color_parse

extern __typeof (gdk_color_to_string) IA__gdk_color_to_string __attribute((visibility("hidden")));
#define gdk_color_to_string IA__gdk_color_to_string

#endif
#endif
#if IN_HEADER(__GDK_COLOR_H__)
#if IN_FILE(__GDK_COLOR_X11_C__)
extern __typeof (gdk_colormap_new) IA__gdk_colormap_new __attribute((visibility("hidden")));
#define gdk_colormap_new IA__gdk_colormap_new

extern __typeof (gdk_colormap_get_type) IA__gdk_colormap_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_colormap_get_type IA__gdk_colormap_get_type

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_colormap_change) IA__gdk_colormap_change __attribute((visibility("hidden")));
#define gdk_colormap_change IA__gdk_colormap_change

extern __typeof (gdk_colors_alloc) IA__gdk_colors_alloc __attribute((visibility("hidden")));
#define gdk_colors_alloc IA__gdk_colors_alloc

extern __typeof (gdk_colors_free) IA__gdk_colors_free __attribute((visibility("hidden")));
#define gdk_colors_free IA__gdk_colors_free

extern __typeof (gdk_colormap_get_system_size) IA__gdk_colormap_get_system_size __attribute((visibility("hidden")));
#define gdk_colormap_get_system_size IA__gdk_colormap_get_system_size

extern __typeof (gdk_color_change) IA__gdk_color_change __attribute((visibility("hidden")));
#define gdk_color_change IA__gdk_color_change

#endif
extern __typeof (gdk_colormap_alloc_colors) IA__gdk_colormap_alloc_colors __attribute((visibility("hidden")));
#define gdk_colormap_alloc_colors IA__gdk_colormap_alloc_colors

extern __typeof (gdk_colormap_free_colors) IA__gdk_colormap_free_colors __attribute((visibility("hidden")));
#define gdk_colormap_free_colors IA__gdk_colormap_free_colors

extern __typeof (gdk_colormap_query_color) IA__gdk_colormap_query_color __attribute((visibility("hidden")));
#define gdk_colormap_query_color IA__gdk_colormap_query_color

extern __typeof (gdk_colormap_get_screen) IA__gdk_colormap_get_screen __attribute((visibility("hidden")));
#define gdk_colormap_get_screen IA__gdk_colormap_get_screen

#endif
#endif
#if IN_HEADER(__GDK_CURSOR_H__)
#if IN_FILE(__GDK_CURSOR_C__)
extern __typeof (gdk_cursor_get_type) IA__gdk_cursor_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_cursor_get_type IA__gdk_cursor_get_type

extern __typeof (gdk_cursor_get_cursor_type) IA__gdk_cursor_get_cursor_type __attribute((visibility("hidden")));
#define gdk_cursor_get_cursor_type IA__gdk_cursor_get_cursor_type

extern __typeof (gdk_cursor_new) IA__gdk_cursor_new __attribute((visibility("hidden")));
#define gdk_cursor_new IA__gdk_cursor_new

extern __typeof (gdk_cursor_ref) IA__gdk_cursor_ref __attribute((visibility("hidden")));
#define gdk_cursor_ref IA__gdk_cursor_ref

extern __typeof (gdk_cursor_unref) IA__gdk_cursor_unref __attribute((visibility("hidden")));
#define gdk_cursor_unref IA__gdk_cursor_unref

#endif
#endif
#if IN_HEADER(__GDK_CURSOR_H__)
#if IN_FILE(__GDK_CURSOR_X11_C__)
extern __typeof (gdk_cursor_get_display) IA__gdk_cursor_get_display __attribute((visibility("hidden")));
#define gdk_cursor_get_display IA__gdk_cursor_get_display

extern __typeof (gdk_cursor_new_for_display) IA__gdk_cursor_new_for_display __attribute((visibility("hidden")));
#define gdk_cursor_new_for_display IA__gdk_cursor_new_for_display

extern __typeof (gdk_cursor_new_from_pixbuf) IA__gdk_cursor_new_from_pixbuf __attribute((visibility("hidden")));
#define gdk_cursor_new_from_pixbuf IA__gdk_cursor_new_from_pixbuf

extern __typeof (gdk_cursor_new_from_pixmap) IA__gdk_cursor_new_from_pixmap __attribute((visibility("hidden")));
#define gdk_cursor_new_from_pixmap IA__gdk_cursor_new_from_pixmap

extern __typeof (gdk_cursor_new_from_name) IA__gdk_cursor_new_from_name __attribute((visibility("hidden")));
#define gdk_cursor_new_from_name IA__gdk_cursor_new_from_name

extern __typeof (gdk_cursor_get_image) IA__gdk_cursor_get_image __attribute((visibility("hidden")));
#define gdk_cursor_get_image IA__gdk_cursor_get_image

#endif
#endif
#if IN_HEADER(__GDK_INPUT_H__)
#if IN_FILE(__GDK_INPUT_C__)
extern __typeof (gdk_device_free_history) IA__gdk_device_free_history __attribute((visibility("hidden")));
#define gdk_device_free_history IA__gdk_device_free_history

extern __typeof (gdk_device_get_axis) IA__gdk_device_get_axis __attribute((visibility("hidden")));
#define gdk_device_get_axis IA__gdk_device_get_axis

extern __typeof (gdk_device_get_axis_use) IA__gdk_device_get_axis_use __attribute((visibility("hidden")));
#define gdk_device_get_axis_use IA__gdk_device_get_axis_use

extern __typeof (gdk_device_get_has_cursor) IA__gdk_device_get_has_cursor __attribute((visibility("hidden")));
#define gdk_device_get_has_cursor IA__gdk_device_get_has_cursor

extern __typeof (gdk_device_get_history) IA__gdk_device_get_history __attribute((visibility("hidden")));
#define gdk_device_get_history IA__gdk_device_get_history

extern __typeof (gdk_device_get_key) IA__gdk_device_get_key __attribute((visibility("hidden")));
#define gdk_device_get_key IA__gdk_device_get_key

extern __typeof (gdk_device_get_mode) IA__gdk_device_get_mode __attribute((visibility("hidden")));
#define gdk_device_get_mode IA__gdk_device_get_mode

extern __typeof (gdk_device_get_name) IA__gdk_device_get_name __attribute((visibility("hidden")));
#define gdk_device_get_name IA__gdk_device_get_name

extern __typeof (gdk_device_get_n_axes) IA__gdk_device_get_n_axes __attribute((visibility("hidden")));
#define gdk_device_get_n_axes IA__gdk_device_get_n_axes

extern __typeof (gdk_device_get_n_keys) IA__gdk_device_get_n_keys __attribute((visibility("hidden")));
#define gdk_device_get_n_keys IA__gdk_device_get_n_keys

extern __typeof (gdk_device_get_source) IA__gdk_device_get_source __attribute((visibility("hidden")));
#define gdk_device_get_source IA__gdk_device_get_source

extern __typeof (gdk_device_get_type) IA__gdk_device_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_device_get_type IA__gdk_device_get_type

extern __typeof (gdk_device_set_axis_use) IA__gdk_device_set_axis_use __attribute((visibility("hidden")));
#define gdk_device_set_axis_use IA__gdk_device_set_axis_use

extern __typeof (gdk_device_set_key) IA__gdk_device_set_key __attribute((visibility("hidden")));
#define gdk_device_set_key IA__gdk_device_set_key

extern __typeof (gdk_device_set_source) IA__gdk_device_set_source __attribute((visibility("hidden")));
#define gdk_device_set_source IA__gdk_device_set_source

extern __typeof (gdk_devices_list) IA__gdk_devices_list __attribute((visibility("hidden")));
#define gdk_devices_list IA__gdk_devices_list

extern __typeof (gdk_input_set_extension_events) IA__gdk_input_set_extension_events __attribute((visibility("hidden")));
#define gdk_input_set_extension_events IA__gdk_input_set_extension_events

#endif
#endif
#if IN_HEADER(__GDK_INPUT_H__)
#if IN_FILE(__GDK_DISPLAY_C__)
extern __typeof (gdk_device_get_core_pointer) IA__gdk_device_get_core_pointer __attribute((visibility("hidden")));
#define gdk_device_get_core_pointer IA__gdk_device_get_core_pointer

#endif
#endif
#if IN_HEADER(__GDK_INPUT_H__)
#if IN_FILE(__GDK_INPUT_X11_C__)
extern __typeof (gdk_device_get_state) IA__gdk_device_get_state __attribute((visibility("hidden")));
#define gdk_device_get_state IA__gdk_device_get_state

#endif
#endif
#if IN_HEADER(__GDK_INPUT_H__)
#if IN_FILE(__GDK_INPUT_XFREE_C__)
extern __typeof (gdk_device_set_mode) IA__gdk_device_set_mode __attribute((visibility("hidden")));
#define gdk_device_set_mode IA__gdk_device_set_mode

#endif
#endif
#if IN_HEADER(__GDK_INPUT_H__)
#if IN_FILE(__GDK_INPUT_NONE_C__)
extern __typeof (gdk_device_get_state) IA__gdk_device_get_state __attribute((visibility("hidden")));
#define gdk_device_get_state IA__gdk_device_get_state

extern __typeof (gdk_device_set_mode) IA__gdk_device_set_mode __attribute((visibility("hidden")));
#define gdk_device_set_mode IA__gdk_device_set_mode

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_EVENTS_X11_C__)
extern __typeof (gdk_display_add_client_message_filter) IA__gdk_display_add_client_message_filter __attribute((visibility("hidden")));
#define gdk_display_add_client_message_filter IA__gdk_display_add_client_message_filter

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_DISPLAY_C__)
extern __typeof (gdk_display_close) IA__gdk_display_close __attribute((visibility("hidden")));
#define gdk_display_close IA__gdk_display_close

extern __typeof (gdk_display_get_core_pointer) IA__gdk_display_get_core_pointer __attribute((visibility("hidden")));
#define gdk_display_get_core_pointer IA__gdk_display_get_core_pointer

extern __typeof (gdk_display_get_event) IA__gdk_display_get_event __attribute((visibility("hidden")));
#define gdk_display_get_event IA__gdk_display_get_event

extern __typeof (gdk_display_get_pointer) IA__gdk_display_get_pointer __attribute((visibility("hidden")));
#define gdk_display_get_pointer IA__gdk_display_get_pointer

extern __typeof (gdk_display_get_type) IA__gdk_display_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_display_get_type IA__gdk_display_get_type

extern __typeof (gdk_display_get_window_at_pointer) IA__gdk_display_get_window_at_pointer __attribute((visibility("hidden")));
#define gdk_display_get_window_at_pointer IA__gdk_display_get_window_at_pointer

extern __typeof (gdk_display_is_closed) IA__gdk_display_is_closed __attribute((visibility("hidden")));
#define gdk_display_is_closed IA__gdk_display_is_closed

extern __typeof (gdk_display_peek_event) IA__gdk_display_peek_event __attribute((visibility("hidden")));
#define gdk_display_peek_event IA__gdk_display_peek_event

extern __typeof (gdk_display_put_event) IA__gdk_display_put_event __attribute((visibility("hidden")));
#define gdk_display_put_event IA__gdk_display_put_event

extern __typeof (gdk_display_set_pointer_hooks) IA__gdk_display_set_pointer_hooks __attribute((visibility("hidden")));
#define gdk_display_set_pointer_hooks IA__gdk_display_set_pointer_hooks

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_WINDOW_X11_C__)
extern __typeof (gdk_display_warp_pointer) IA__gdk_display_warp_pointer __attribute((visibility("hidden")));
#define gdk_display_warp_pointer IA__gdk_display_warp_pointer

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_DISPLAY_MANAGER_C__)
extern __typeof (gdk_display_get_default) IA__gdk_display_get_default __attribute((visibility("hidden")));
#define gdk_display_get_default IA__gdk_display_get_default

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_CURSOR_X11_C__)
extern __typeof (gdk_display_get_default_cursor_size) IA__gdk_display_get_default_cursor_size __attribute((visibility("hidden")));
#define gdk_display_get_default_cursor_size IA__gdk_display_get_default_cursor_size

extern __typeof (gdk_display_get_maximal_cursor_size) IA__gdk_display_get_maximal_cursor_size __attribute((visibility("hidden")));
#define gdk_display_get_maximal_cursor_size IA__gdk_display_get_maximal_cursor_size

extern __typeof (gdk_display_supports_cursor_alpha) IA__gdk_display_supports_cursor_alpha __attribute((visibility("hidden")));
#define gdk_display_supports_cursor_alpha IA__gdk_display_supports_cursor_alpha

extern __typeof (gdk_display_supports_cursor_color) IA__gdk_display_supports_cursor_color __attribute((visibility("hidden")));
#define gdk_display_supports_cursor_color IA__gdk_display_supports_cursor_color

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_DISPLAY_X11_C__)
extern __typeof (gdk_display_beep) IA__gdk_display_beep __attribute((visibility("hidden")));
#define gdk_display_beep IA__gdk_display_beep

extern __typeof (gdk_display_sync) IA__gdk_display_sync __attribute((visibility("hidden")));
#define gdk_display_sync IA__gdk_display_sync

extern __typeof (gdk_display_flush) IA__gdk_display_flush __attribute((visibility("hidden")));
#define gdk_display_flush IA__gdk_display_flush

extern __typeof (gdk_display_get_default_group) IA__gdk_display_get_default_group __attribute((visibility("hidden")));
#define gdk_display_get_default_group IA__gdk_display_get_default_group

extern __typeof (gdk_display_get_default_screen) IA__gdk_display_get_default_screen __attribute((visibility("hidden")));
#define gdk_display_get_default_screen IA__gdk_display_get_default_screen

extern __typeof (gdk_display_get_name) IA__gdk_display_get_name __attribute((visibility("hidden")));
#define gdk_display_get_name IA__gdk_display_get_name

extern __typeof (gdk_display_get_n_screens) IA__gdk_display_get_n_screens __attribute((visibility("hidden")));
#define gdk_display_get_n_screens IA__gdk_display_get_n_screens

extern __typeof (gdk_display_get_screen) IA__gdk_display_get_screen __attribute((visibility("hidden")));
#define gdk_display_get_screen IA__gdk_display_get_screen

extern __typeof (gdk_display_pointer_ungrab) IA__gdk_display_pointer_ungrab __attribute((visibility("hidden")));
#define gdk_display_pointer_ungrab IA__gdk_display_pointer_ungrab

extern __typeof (gdk_display_keyboard_ungrab) IA__gdk_display_keyboard_ungrab __attribute((visibility("hidden")));
#define gdk_display_keyboard_ungrab IA__gdk_display_keyboard_ungrab

extern __typeof (gdk_display_open) IA__gdk_display_open __attribute((visibility("hidden")));
#define gdk_display_open IA__gdk_display_open

extern __typeof (gdk_display_request_selection_notification) IA__gdk_display_request_selection_notification __attribute((visibility("hidden")));
#define gdk_display_request_selection_notification IA__gdk_display_request_selection_notification

extern __typeof (gdk_display_store_clipboard) IA__gdk_display_store_clipboard __attribute((visibility("hidden")));
#define gdk_display_store_clipboard IA__gdk_display_store_clipboard

extern __typeof (gdk_display_supports_clipboard_persistence) IA__gdk_display_supports_clipboard_persistence __attribute((visibility("hidden")));
#define gdk_display_supports_clipboard_persistence IA__gdk_display_supports_clipboard_persistence

extern __typeof (gdk_display_supports_selection_notification) IA__gdk_display_supports_selection_notification __attribute((visibility("hidden")));
#define gdk_display_supports_selection_notification IA__gdk_display_supports_selection_notification

extern __typeof (gdk_display_supports_shapes) IA__gdk_display_supports_shapes __attribute((visibility("hidden")));
#define gdk_display_supports_shapes IA__gdk_display_supports_shapes

extern __typeof (gdk_display_supports_input_shapes) IA__gdk_display_supports_input_shapes __attribute((visibility("hidden")));
#define gdk_display_supports_input_shapes IA__gdk_display_supports_input_shapes

extern __typeof (gdk_display_supports_composite) IA__gdk_display_supports_composite __attribute((visibility("hidden")));
#define gdk_display_supports_composite IA__gdk_display_supports_composite

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_INPUT_C__)
extern __typeof (gdk_display_list_devices) IA__gdk_display_list_devices __attribute((visibility("hidden")));
#define gdk_display_list_devices IA__gdk_display_list_devices

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_C__)
extern __typeof (gdk_display_open_default_libgtk_only) IA__gdk_display_open_default_libgtk_only __attribute((visibility("hidden")));
#define gdk_display_open_default_libgtk_only IA__gdk_display_open_default_libgtk_only

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_H__)
#if IN_FILE(__GDK_EVENTS_C__)
extern __typeof (gdk_display_set_double_click_distance) IA__gdk_display_set_double_click_distance __attribute((visibility("hidden")));
#define gdk_display_set_double_click_distance IA__gdk_display_set_double_click_distance

extern __typeof (gdk_display_set_double_click_time) IA__gdk_display_set_double_click_time __attribute((visibility("hidden")));
#define gdk_display_set_double_click_time IA__gdk_display_set_double_click_time

#endif
#endif
#if IN_HEADER(__GDK_DISPLAY_MANAGER_H__)
#if IN_FILE(__GDK_DISPLAY_MANAGER_C__)
extern __typeof (gdk_display_manager_get) IA__gdk_display_manager_get __attribute((visibility("hidden")));
#define gdk_display_manager_get IA__gdk_display_manager_get

extern __typeof (gdk_display_manager_get_type) IA__gdk_display_manager_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_display_manager_get_type IA__gdk_display_manager_get_type

extern __typeof (gdk_display_manager_list_displays) IA__gdk_display_manager_list_displays __attribute((visibility("hidden")));
#define gdk_display_manager_list_displays IA__gdk_display_manager_list_displays

extern __typeof (gdk_display_manager_set_default_display) IA__gdk_display_manager_set_default_display __attribute((visibility("hidden")));
#define gdk_display_manager_set_default_display IA__gdk_display_manager_set_default_display

extern __typeof (gdk_display_manager_get_default_display) IA__gdk_display_manager_get_default_display __attribute((visibility("hidden")));
#define gdk_display_manager_get_default_display IA__gdk_display_manager_get_default_display

#endif
#endif
#if IN_HEADER(__GDK_DND_H__)
#if IN_FILE(__GDK_DND_X11_C__)
extern __typeof (gdk_drag_abort) IA__gdk_drag_abort __attribute((visibility("hidden")));
#define gdk_drag_abort IA__gdk_drag_abort

extern __typeof (gdk_drag_begin) IA__gdk_drag_begin __attribute((visibility("hidden")));
#define gdk_drag_begin IA__gdk_drag_begin

extern __typeof (gdk_drag_context_get_type) IA__gdk_drag_context_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_drag_context_get_type IA__gdk_drag_context_get_type

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_drag_context_new) IA__gdk_drag_context_new __attribute((visibility("hidden")));
#define gdk_drag_context_new IA__gdk_drag_context_new

extern __typeof (gdk_drag_context_ref) IA__gdk_drag_context_ref __attribute((visibility("hidden")));
#define gdk_drag_context_ref IA__gdk_drag_context_ref

extern __typeof (gdk_drag_context_unref) IA__gdk_drag_context_unref __attribute((visibility("hidden")));
#define gdk_drag_context_unref IA__gdk_drag_context_unref

#endif
extern __typeof (gdk_drag_drop) IA__gdk_drag_drop __attribute((visibility("hidden")));
#define gdk_drag_drop IA__gdk_drag_drop

extern __typeof (gdk_drag_drop_succeeded) IA__gdk_drag_drop_succeeded __attribute((visibility("hidden")));
#define gdk_drag_drop_succeeded IA__gdk_drag_drop_succeeded

extern __typeof (gdk_drag_find_window_for_screen) IA__gdk_drag_find_window_for_screen __attribute((visibility("hidden")));
#define gdk_drag_find_window_for_screen IA__gdk_drag_find_window_for_screen

extern __typeof (gdk_drag_get_protocol_for_display) IA__gdk_drag_get_protocol_for_display __attribute((visibility("hidden")));
#define gdk_drag_get_protocol_for_display IA__gdk_drag_get_protocol_for_display

extern __typeof (gdk_drag_get_selection) IA__gdk_drag_get_selection __attribute((visibility("hidden")));
#define gdk_drag_get_selection IA__gdk_drag_get_selection

extern __typeof (gdk_drag_motion) IA__gdk_drag_motion __attribute((visibility("hidden")));
#define gdk_drag_motion IA__gdk_drag_motion

extern __typeof (gdk_drag_status) IA__gdk_drag_status __attribute((visibility("hidden")));
#define gdk_drag_status IA__gdk_drag_status

extern __typeof (gdk_drop_finish) IA__gdk_drop_finish __attribute((visibility("hidden")));
#define gdk_drop_finish IA__gdk_drop_finish

extern __typeof (gdk_drop_reply) IA__gdk_drop_reply __attribute((visibility("hidden")));
#define gdk_drop_reply IA__gdk_drop_reply

#endif
#endif
#if IN_HEADER(__GDK_DND_H__)
#if IN_FILE(__GDK_DND_C__)
extern __typeof (gdk_drag_context_get_actions) IA__gdk_drag_context_get_actions __attribute((visibility("hidden")));
#define gdk_drag_context_get_actions IA__gdk_drag_context_get_actions

extern __typeof (gdk_drag_context_get_selected_action) IA__gdk_drag_context_get_selected_action __attribute((visibility("hidden")));
#define gdk_drag_context_get_selected_action IA__gdk_drag_context_get_selected_action

extern __typeof (gdk_drag_context_get_suggested_action) IA__gdk_drag_context_get_suggested_action __attribute((visibility("hidden")));
#define gdk_drag_context_get_suggested_action IA__gdk_drag_context_get_suggested_action

extern __typeof (gdk_drag_context_list_targets) IA__gdk_drag_context_list_targets __attribute((visibility("hidden")));
#define gdk_drag_context_list_targets IA__gdk_drag_context_list_targets

extern __typeof (gdk_drag_context_get_source_window) IA__gdk_drag_context_get_source_window __attribute((visibility("hidden")));
#define gdk_drag_context_get_source_window IA__gdk_drag_context_get_source_window

extern __typeof (gdk_drag_context_get_dest_window) IA__gdk_drag_context_get_dest_window __attribute((visibility("hidden")));
#define gdk_drag_context_get_dest_window IA__gdk_drag_context_get_dest_window

extern __typeof (gdk_drag_context_get_protocol) IA__gdk_drag_context_get_protocol __attribute((visibility("hidden")));
#define gdk_drag_context_get_protocol IA__gdk_drag_context_get_protocol

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_drag_find_window) IA__gdk_drag_find_window __attribute((visibility("hidden")));
#define gdk_drag_find_window IA__gdk_drag_find_window

extern __typeof (gdk_drag_get_protocol) IA__gdk_drag_get_protocol __attribute((visibility("hidden")));
#define gdk_drag_get_protocol IA__gdk_drag_get_protocol

#endif
#endif
#endif
#if IN_HEADER(__GDK_DRAWABLE_H__)
#if IN_FILE(__GDK_DRAW_C__)
extern __typeof (gdk_drawable_copy_to_image) IA__gdk_drawable_copy_to_image __attribute((visibility("hidden")));
#define gdk_drawable_copy_to_image IA__gdk_drawable_copy_to_image

extern __typeof (gdk_drawable_get_clip_region) IA__gdk_drawable_get_clip_region __attribute((visibility("hidden")));
#define gdk_drawable_get_clip_region IA__gdk_drawable_get_clip_region

extern __typeof (gdk_drawable_get_colormap) IA__gdk_drawable_get_colormap __attribute((visibility("hidden")));
#define gdk_drawable_get_colormap IA__gdk_drawable_get_colormap

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_drawable_get_data) IA__gdk_drawable_get_data __attribute((visibility("hidden")));
#define gdk_drawable_get_data IA__gdk_drawable_get_data

extern __typeof (gdk_drawable_set_data) IA__gdk_drawable_set_data __attribute((visibility("hidden")));
#define gdk_drawable_set_data IA__gdk_drawable_set_data

extern __typeof (gdk_drawable_ref) IA__gdk_drawable_ref __attribute((visibility("hidden")));
#define gdk_drawable_ref IA__gdk_drawable_ref

extern __typeof (gdk_drawable_unref) IA__gdk_drawable_unref __attribute((visibility("hidden")));
#define gdk_drawable_unref IA__gdk_drawable_unref

extern __typeof (gdk_draw_string) IA__gdk_draw_string __attribute((visibility("hidden")));
#define gdk_draw_string IA__gdk_draw_string

extern __typeof (gdk_draw_text) IA__gdk_draw_text __attribute((visibility("hidden")));
#define gdk_draw_text IA__gdk_draw_text

extern __typeof (gdk_draw_text_wc) IA__gdk_draw_text_wc __attribute((visibility("hidden")));
#define gdk_draw_text_wc IA__gdk_draw_text_wc

extern __typeof (gdk_drawable_get_display) IA__gdk_drawable_get_display __attribute((visibility("hidden")));
#define gdk_drawable_get_display IA__gdk_drawable_get_display

extern __typeof (gdk_drawable_get_screen) IA__gdk_drawable_get_screen __attribute((visibility("hidden")));
#define gdk_drawable_get_screen IA__gdk_drawable_get_screen

extern __typeof (gdk_drawable_get_size) IA__gdk_drawable_get_size __attribute((visibility("hidden")));
#define gdk_drawable_get_size IA__gdk_drawable_get_size

extern __typeof (gdk_drawable_get_visual) IA__gdk_drawable_get_visual __attribute((visibility("hidden")));
#define gdk_drawable_get_visual IA__gdk_drawable_get_visual

#endif
extern __typeof (gdk_drawable_get_depth) IA__gdk_drawable_get_depth __attribute((visibility("hidden")));
#define gdk_drawable_get_depth IA__gdk_drawable_get_depth

extern __typeof (gdk_drawable_get_image) IA__gdk_drawable_get_image __attribute((visibility("hidden")));
#define gdk_drawable_get_image IA__gdk_drawable_get_image

extern __typeof (gdk_drawable_get_type) IA__gdk_drawable_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_drawable_get_type IA__gdk_drawable_get_type

extern __typeof (gdk_drawable_get_visible_region) IA__gdk_drawable_get_visible_region __attribute((visibility("hidden")));
#define gdk_drawable_get_visible_region IA__gdk_drawable_get_visible_region

extern __typeof (gdk_drawable_set_colormap) IA__gdk_drawable_set_colormap __attribute((visibility("hidden")));
#define gdk_drawable_set_colormap IA__gdk_drawable_set_colormap

extern __typeof (gdk_draw_arc) IA__gdk_draw_arc __attribute((visibility("hidden")));
#define gdk_draw_arc IA__gdk_draw_arc

extern __typeof (gdk_draw_drawable) IA__gdk_draw_drawable __attribute((visibility("hidden")));
#define gdk_draw_drawable IA__gdk_draw_drawable

extern __typeof (gdk_draw_glyphs) IA__gdk_draw_glyphs __attribute((visibility("hidden")));
#define gdk_draw_glyphs IA__gdk_draw_glyphs

extern __typeof (gdk_draw_glyphs_transformed) IA__gdk_draw_glyphs_transformed __attribute((visibility("hidden")));
#define gdk_draw_glyphs_transformed IA__gdk_draw_glyphs_transformed

extern __typeof (gdk_draw_image) IA__gdk_draw_image __attribute((visibility("hidden")));
#define gdk_draw_image IA__gdk_draw_image

extern __typeof (gdk_draw_line) IA__gdk_draw_line __attribute((visibility("hidden")));
#define gdk_draw_line IA__gdk_draw_line

extern __typeof (gdk_draw_lines) IA__gdk_draw_lines __attribute((visibility("hidden")));
#define gdk_draw_lines IA__gdk_draw_lines

extern __typeof (gdk_draw_pixbuf) IA__gdk_draw_pixbuf __attribute((visibility("hidden")));
#define gdk_draw_pixbuf IA__gdk_draw_pixbuf

extern __typeof (gdk_draw_point) IA__gdk_draw_point __attribute((visibility("hidden")));
#define gdk_draw_point IA__gdk_draw_point

extern __typeof (gdk_draw_points) IA__gdk_draw_points __attribute((visibility("hidden")));
#define gdk_draw_points IA__gdk_draw_points

extern __typeof (gdk_draw_polygon) IA__gdk_draw_polygon __attribute((visibility("hidden")));
#define gdk_draw_polygon IA__gdk_draw_polygon

extern __typeof (gdk_draw_rectangle) IA__gdk_draw_rectangle __attribute((visibility("hidden")));
#define gdk_draw_rectangle IA__gdk_draw_rectangle

extern __typeof (gdk_draw_segments) IA__gdk_draw_segments __attribute((visibility("hidden")));
#define gdk_draw_segments IA__gdk_draw_segments

extern __typeof (gdk_draw_trapezoids) IA__gdk_draw_trapezoids __attribute((visibility("hidden")));
#define gdk_draw_trapezoids IA__gdk_draw_trapezoids

#endif
#endif
#if IN_HEADER(__GDK_DRAWABLE_H__)
#if IN_FILE(__GDK_PANGO_C__)
extern __typeof (gdk_draw_layout) IA__gdk_draw_layout __attribute((visibility("hidden")));
#define gdk_draw_layout IA__gdk_draw_layout

extern __typeof (gdk_draw_layout_line) IA__gdk_draw_layout_line __attribute((visibility("hidden")));
#define gdk_draw_layout_line IA__gdk_draw_layout_line

extern __typeof (gdk_draw_layout_line_with_colors) IA__gdk_draw_layout_line_with_colors __attribute((visibility("hidden")));
#define gdk_draw_layout_line_with_colors IA__gdk_draw_layout_line_with_colors

extern __typeof (gdk_draw_layout_with_colors) IA__gdk_draw_layout_with_colors __attribute((visibility("hidden")));
#define gdk_draw_layout_with_colors IA__gdk_draw_layout_with_colors

#endif
#endif
#if IN_HEADER(__GDK_GC_H__)
#if IN_FILE(__GDK_GC_C__)
extern __typeof (gdk_gc_new) IA__gdk_gc_new __attribute((visibility("hidden")));
#define gdk_gc_new IA__gdk_gc_new

extern __typeof (gdk_gc_get_type) IA__gdk_gc_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_gc_get_type IA__gdk_gc_get_type

extern __typeof (gdk_gc_new_with_values) IA__gdk_gc_new_with_values __attribute((visibility("hidden")));
#define gdk_gc_new_with_values IA__gdk_gc_new_with_values

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_gc_ref) IA__gdk_gc_ref __attribute((visibility("hidden")));
#define gdk_gc_ref IA__gdk_gc_ref

extern __typeof (gdk_gc_unref) IA__gdk_gc_unref __attribute((visibility("hidden")));
#define gdk_gc_unref IA__gdk_gc_unref

extern __typeof (gdk_gc_set_font) IA__gdk_gc_set_font __attribute((visibility("hidden")));
#define gdk_gc_set_font IA__gdk_gc_set_font

#endif
extern __typeof (gdk_gc_get_values) IA__gdk_gc_get_values __attribute((visibility("hidden")));
#define gdk_gc_get_values IA__gdk_gc_get_values

extern __typeof (gdk_gc_set_values) IA__gdk_gc_set_values __attribute((visibility("hidden")));
#define gdk_gc_set_values IA__gdk_gc_set_values

extern __typeof (gdk_gc_set_foreground) IA__gdk_gc_set_foreground __attribute((visibility("hidden")));
#define gdk_gc_set_foreground IA__gdk_gc_set_foreground

extern __typeof (gdk_gc_set_background) IA__gdk_gc_set_background __attribute((visibility("hidden")));
#define gdk_gc_set_background IA__gdk_gc_set_background

extern __typeof (gdk_gc_set_function) IA__gdk_gc_set_function __attribute((visibility("hidden")));
#define gdk_gc_set_function IA__gdk_gc_set_function

extern __typeof (gdk_gc_set_fill) IA__gdk_gc_set_fill __attribute((visibility("hidden")));
#define gdk_gc_set_fill IA__gdk_gc_set_fill

extern __typeof (gdk_gc_set_tile) IA__gdk_gc_set_tile __attribute((visibility("hidden")));
#define gdk_gc_set_tile IA__gdk_gc_set_tile

extern __typeof (gdk_gc_set_stipple) IA__gdk_gc_set_stipple __attribute((visibility("hidden")));
#define gdk_gc_set_stipple IA__gdk_gc_set_stipple

extern __typeof (gdk_gc_set_ts_origin) IA__gdk_gc_set_ts_origin __attribute((visibility("hidden")));
#define gdk_gc_set_ts_origin IA__gdk_gc_set_ts_origin

extern __typeof (gdk_gc_set_clip_origin) IA__gdk_gc_set_clip_origin __attribute((visibility("hidden")));
#define gdk_gc_set_clip_origin IA__gdk_gc_set_clip_origin

extern __typeof (gdk_gc_set_clip_mask) IA__gdk_gc_set_clip_mask __attribute((visibility("hidden")));
#define gdk_gc_set_clip_mask IA__gdk_gc_set_clip_mask

extern __typeof (gdk_gc_set_clip_rectangle) IA__gdk_gc_set_clip_rectangle __attribute((visibility("hidden")));
#define gdk_gc_set_clip_rectangle IA__gdk_gc_set_clip_rectangle

extern __typeof (gdk_gc_set_clip_region) IA__gdk_gc_set_clip_region __attribute((visibility("hidden")));
#define gdk_gc_set_clip_region IA__gdk_gc_set_clip_region

extern __typeof (gdk_gc_set_subwindow) IA__gdk_gc_set_subwindow __attribute((visibility("hidden")));
#define gdk_gc_set_subwindow IA__gdk_gc_set_subwindow

extern __typeof (gdk_gc_set_exposures) IA__gdk_gc_set_exposures __attribute((visibility("hidden")));
#define gdk_gc_set_exposures IA__gdk_gc_set_exposures

extern __typeof (gdk_gc_set_line_attributes) IA__gdk_gc_set_line_attributes __attribute((visibility("hidden")));
#define gdk_gc_set_line_attributes IA__gdk_gc_set_line_attributes

extern __typeof (gdk_gc_set_dashes) IA__gdk_gc_set_dashes __attribute((visibility("hidden")));
#define gdk_gc_set_dashes IA__gdk_gc_set_dashes

extern __typeof (gdk_gc_offset) IA__gdk_gc_offset __attribute((visibility("hidden")));
#define gdk_gc_offset IA__gdk_gc_offset

extern __typeof (gdk_gc_copy) IA__gdk_gc_copy __attribute((visibility("hidden")));
#define gdk_gc_copy IA__gdk_gc_copy

extern __typeof (gdk_gc_get_colormap) IA__gdk_gc_get_colormap __attribute((visibility("hidden")));
#define gdk_gc_get_colormap IA__gdk_gc_get_colormap

extern __typeof (gdk_gc_set_colormap) IA__gdk_gc_set_colormap __attribute((visibility("hidden")));
#define gdk_gc_set_colormap IA__gdk_gc_set_colormap

extern __typeof (gdk_gc_set_rgb_bg_color) IA__gdk_gc_set_rgb_bg_color __attribute((visibility("hidden")));
#define gdk_gc_set_rgb_bg_color IA__gdk_gc_set_rgb_bg_color

extern __typeof (gdk_gc_set_rgb_fg_color) IA__gdk_gc_set_rgb_fg_color __attribute((visibility("hidden")));
#define gdk_gc_set_rgb_fg_color IA__gdk_gc_set_rgb_fg_color

#endif
#endif
#if IN_HEADER(__GDK_GC_H__)
#if IN_FILE(__GDK_GC_X11_C__)
extern __typeof (gdk_gc_get_screen) IA__gdk_gc_get_screen __attribute((visibility("hidden")));
#define gdk_gc_get_screen IA__gdk_gc_get_screen

#endif
#endif
#if IN_HEADER(__GDK_PIXMAP_X11_H__)
#if IN_FILE(__GDK_PIXMAP_X11_C__)
#ifdef GDK_WINDOWING_X11
extern __typeof (gdk_pixmap_impl_x11_get_type) IA__gdk_pixmap_impl_x11_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_pixmap_impl_x11_get_type IA__gdk_pixmap_impl_x11_get_type

#endif
#endif
#endif
#if IN_HEADER(__GDK_WINDOW_X11_H__)
#if IN_FILE(__GDK_WINDOW_X11_C__)
#ifdef GDK_WINDOWING_X11
extern __typeof (gdk_window_impl_x11_get_type) IA__gdk_window_impl_x11_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_window_impl_x11_get_type IA__gdk_window_impl_x11_get_type

#endif
#endif
#endif
#if IN_HEADER(__GDK_WINDOW_H__)
#if IN_FILE(__GDK_WINDOW_C__)
extern __typeof (gdk_get_default_root_window) IA__gdk_get_default_root_window __attribute((visibility("hidden")));
#define gdk_get_default_root_window IA__gdk_get_default_root_window

extern __typeof (gdk_window_new) IA__gdk_window_new __attribute((visibility("hidden")));
#define gdk_window_new IA__gdk_window_new

extern __typeof (gdk_window_show_unraised) IA__gdk_window_show_unraised __attribute((visibility("hidden")));
#define gdk_window_show_unraised IA__gdk_window_show_unraised

extern __typeof (gdk_window_show) IA__gdk_window_show __attribute((visibility("hidden")));
#define gdk_window_show IA__gdk_window_show

extern __typeof (gdk_window_hide) IA__gdk_window_hide __attribute((visibility("hidden")));
#define gdk_window_hide IA__gdk_window_hide

extern __typeof (gdk_window_withdraw) IA__gdk_window_withdraw __attribute((visibility("hidden")));
#define gdk_window_withdraw IA__gdk_window_withdraw

extern __typeof (gdk_window_get_events) IA__gdk_window_get_events __attribute((visibility("hidden")));
#define gdk_window_get_events IA__gdk_window_get_events

extern __typeof (gdk_window_set_events) IA__gdk_window_set_events __attribute((visibility("hidden")));
#define gdk_window_set_events IA__gdk_window_set_events

extern __typeof (gdk_window_raise) IA__gdk_window_raise __attribute((visibility("hidden")));
#define gdk_window_raise IA__gdk_window_raise

extern __typeof (gdk_window_lower) IA__gdk_window_lower __attribute((visibility("hidden")));
#define gdk_window_lower IA__gdk_window_lower

extern __typeof (gdk_window_restack) IA__gdk_window_restack __attribute((visibility("hidden")));
#define gdk_window_restack IA__gdk_window_restack

extern __typeof (gdk_window_move) IA__gdk_window_move __attribute((visibility("hidden")));
#define gdk_window_move IA__gdk_window_move

extern __typeof (gdk_window_resize) IA__gdk_window_resize __attribute((visibility("hidden")));
#define gdk_window_resize IA__gdk_window_resize

extern __typeof (gdk_window_move_resize) IA__gdk_window_move_resize __attribute((visibility("hidden")));
#define gdk_window_move_resize IA__gdk_window_move_resize

extern __typeof (gdk_window_scroll) IA__gdk_window_scroll __attribute((visibility("hidden")));
#define gdk_window_scroll IA__gdk_window_scroll

extern __typeof (gdk_window_move_region) IA__gdk_window_move_region __attribute((visibility("hidden")));
#define gdk_window_move_region IA__gdk_window_move_region

extern __typeof (gdk_window_get_accept_focus) IA__gdk_window_get_accept_focus __attribute((visibility("hidden")));
#define gdk_window_get_accept_focus IA__gdk_window_get_accept_focus

extern __typeof (gdk_window_get_background_pattern) IA__gdk_window_get_background_pattern __attribute((visibility("hidden")));
#define gdk_window_get_background_pattern IA__gdk_window_get_background_pattern

extern __typeof (gdk_window_get_composited) IA__gdk_window_get_composited __attribute((visibility("hidden")));
#define gdk_window_get_composited IA__gdk_window_get_composited

extern __typeof (gdk_window_get_cursor) IA__gdk_window_get_cursor __attribute((visibility("hidden")));
#define gdk_window_get_cursor IA__gdk_window_get_cursor

extern __typeof (gdk_window_get_deskrelative_origin) IA__gdk_window_get_deskrelative_origin __attribute((visibility("hidden")));
#define gdk_window_get_deskrelative_origin IA__gdk_window_get_deskrelative_origin

extern __typeof (gdk_window_get_focus_on_map) IA__gdk_window_get_focus_on_map __attribute((visibility("hidden")));
#define gdk_window_get_focus_on_map IA__gdk_window_get_focus_on_map

extern __typeof (gdk_window_get_geometry) IA__gdk_window_get_geometry __attribute((visibility("hidden")));
#define gdk_window_get_geometry IA__gdk_window_get_geometry

extern __typeof (gdk_window_get_modal_hint) IA__gdk_window_get_modal_hint __attribute((visibility("hidden")));
#define gdk_window_get_modal_hint IA__gdk_window_get_modal_hint

extern __typeof (gdk_window_get_origin) IA__gdk_window_get_origin __attribute((visibility("hidden")));
#define gdk_window_get_origin IA__gdk_window_get_origin

extern __typeof (gdk_window_get_root_coords) IA__gdk_window_get_root_coords __attribute((visibility("hidden")));
#define gdk_window_get_root_coords IA__gdk_window_get_root_coords

extern __typeof (gdk_window_set_background) IA__gdk_window_set_background __attribute((visibility("hidden")));
#define gdk_window_set_background IA__gdk_window_set_background

extern __typeof (gdk_window_set_back_pixmap) IA__gdk_window_set_back_pixmap __attribute((visibility("hidden")));
#define gdk_window_set_back_pixmap IA__gdk_window_set_back_pixmap

extern __typeof (gdk_window_set_cursor) IA__gdk_window_set_cursor __attribute((visibility("hidden")));
#define gdk_window_set_cursor IA__gdk_window_set_cursor

extern __typeof (gdk_window_shape_combine_mask) IA__gdk_window_shape_combine_mask __attribute((visibility("hidden")));
#define gdk_window_shape_combine_mask IA__gdk_window_shape_combine_mask

extern __typeof (gdk_window_shape_combine_region) IA__gdk_window_shape_combine_region __attribute((visibility("hidden")));
#define gdk_window_shape_combine_region IA__gdk_window_shape_combine_region

extern __typeof (gdk_window_set_child_shapes) IA__gdk_window_set_child_shapes __attribute((visibility("hidden")));
#define gdk_window_set_child_shapes IA__gdk_window_set_child_shapes

extern __typeof (gdk_window_merge_child_shapes) IA__gdk_window_merge_child_shapes __attribute((visibility("hidden")));
#define gdk_window_merge_child_shapes IA__gdk_window_merge_child_shapes

extern __typeof (gdk_window_input_shape_combine_mask) IA__gdk_window_input_shape_combine_mask __attribute((visibility("hidden")));
#define gdk_window_input_shape_combine_mask IA__gdk_window_input_shape_combine_mask

extern __typeof (gdk_window_input_shape_combine_region) IA__gdk_window_input_shape_combine_region __attribute((visibility("hidden")));
#define gdk_window_input_shape_combine_region IA__gdk_window_input_shape_combine_region

extern __typeof (gdk_window_set_child_input_shapes) IA__gdk_window_set_child_input_shapes __attribute((visibility("hidden")));
#define gdk_window_set_child_input_shapes IA__gdk_window_set_child_input_shapes

extern __typeof (gdk_window_merge_child_input_shapes) IA__gdk_window_merge_child_input_shapes __attribute((visibility("hidden")));
#define gdk_window_merge_child_input_shapes IA__gdk_window_merge_child_input_shapes

extern __typeof (gdk_window_set_static_gravities) IA__gdk_window_set_static_gravities __attribute((visibility("hidden")));
#define gdk_window_set_static_gravities IA__gdk_window_set_static_gravities

extern __typeof (gdk_window_reparent) IA__gdk_window_reparent __attribute((visibility("hidden")));
#define gdk_window_reparent IA__gdk_window_reparent

extern __typeof (gdk_window_add_filter) IA__gdk_window_add_filter __attribute((visibility("hidden")));
#define gdk_window_add_filter IA__gdk_window_add_filter

extern __typeof (gdk_window_at_pointer) IA__gdk_window_at_pointer __attribute((visibility("hidden")));
#define gdk_window_at_pointer IA__gdk_window_at_pointer

extern __typeof (gdk_window_begin_paint_rect) IA__gdk_window_begin_paint_rect __attribute((visibility("hidden")));
#define gdk_window_begin_paint_rect IA__gdk_window_begin_paint_rect

extern __typeof (gdk_window_begin_paint_region) IA__gdk_window_begin_paint_region __attribute((visibility("hidden")));
#define gdk_window_begin_paint_region IA__gdk_window_begin_paint_region

extern __typeof (gdk_window_clear) IA__gdk_window_clear __attribute((visibility("hidden")));
#define gdk_window_clear IA__gdk_window_clear

extern __typeof (gdk_window_clear_area) IA__gdk_window_clear_area __attribute((visibility("hidden")));
#define gdk_window_clear_area IA__gdk_window_clear_area

extern __typeof (gdk_window_clear_area_e) IA__gdk_window_clear_area_e __attribute((visibility("hidden")));
#define gdk_window_clear_area_e IA__gdk_window_clear_area_e

extern __typeof (gdk_window_constrain_size) IA__gdk_window_constrain_size __attribute((visibility("hidden")));
#define gdk_window_constrain_size IA__gdk_window_constrain_size

extern __typeof (gdk_window_coords_from_parent) IA__gdk_window_coords_from_parent __attribute((visibility("hidden")));
#define gdk_window_coords_from_parent IA__gdk_window_coords_from_parent

extern __typeof (gdk_window_coords_to_parent) IA__gdk_window_coords_to_parent __attribute((visibility("hidden")));
#define gdk_window_coords_to_parent IA__gdk_window_coords_to_parent

extern __typeof (gdk_window_create_similar_surface) IA__gdk_window_create_similar_surface __attribute((visibility("hidden")));
#define gdk_window_create_similar_surface IA__gdk_window_create_similar_surface

extern __typeof (gdk_window_destroy) IA__gdk_window_destroy __attribute((visibility("hidden")));
#define gdk_window_destroy IA__gdk_window_destroy

extern __typeof (gdk_window_end_paint) IA__gdk_window_end_paint __attribute((visibility("hidden")));
#define gdk_window_end_paint IA__gdk_window_end_paint

extern __typeof (gdk_window_flush) IA__gdk_window_flush __attribute((visibility("hidden")));
#define gdk_window_flush IA__gdk_window_flush

extern __typeof (gdk_window_foreign_new) IA__gdk_window_foreign_new __attribute((visibility("hidden")));
#define gdk_window_foreign_new IA__gdk_window_foreign_new

extern __typeof (gdk_window_freeze_toplevel_updates_libgtk_only) IA__gdk_window_freeze_toplevel_updates_libgtk_only __attribute((visibility("hidden")));
#define gdk_window_freeze_toplevel_updates_libgtk_only IA__gdk_window_freeze_toplevel_updates_libgtk_only

extern __typeof (gdk_window_freeze_updates) IA__gdk_window_freeze_updates __attribute((visibility("hidden")));
#define gdk_window_freeze_updates IA__gdk_window_freeze_updates

extern __typeof (gdk_window_get_children) IA__gdk_window_get_children __attribute((visibility("hidden")));
#define gdk_window_get_children IA__gdk_window_get_children

extern __typeof (gdk_window_get_internal_paint_info) IA__gdk_window_get_internal_paint_info __attribute((visibility("hidden")));
#define gdk_window_get_internal_paint_info IA__gdk_window_get_internal_paint_info

extern __typeof (gdk_window_get_parent) IA__gdk_window_get_parent __attribute((visibility("hidden")));
#define gdk_window_get_parent IA__gdk_window_get_parent

extern __typeof (gdk_window_get_effective_parent) IA__gdk_window_get_effective_parent __attribute((visibility("hidden")));
#define gdk_window_get_effective_parent IA__gdk_window_get_effective_parent

extern __typeof (gdk_window_get_pointer) IA__gdk_window_get_pointer __attribute((visibility("hidden")));
#define gdk_window_get_pointer IA__gdk_window_get_pointer

extern __typeof (gdk_window_get_position) IA__gdk_window_get_position __attribute((visibility("hidden")));
#define gdk_window_get_position IA__gdk_window_get_position

extern __typeof (gdk_window_get_state) IA__gdk_window_get_state __attribute((visibility("hidden")));
#define gdk_window_get_state IA__gdk_window_get_state

extern __typeof (gdk_window_get_toplevel) IA__gdk_window_get_toplevel __attribute((visibility("hidden")));
#define gdk_window_get_toplevel IA__gdk_window_get_toplevel

extern __typeof (gdk_window_get_effective_toplevel) IA__gdk_window_get_effective_toplevel __attribute((visibility("hidden")));
#define gdk_window_get_effective_toplevel IA__gdk_window_get_effective_toplevel

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_window_get_toplevels) IA__gdk_window_get_toplevels __attribute((visibility("hidden")));
#define gdk_window_get_toplevels IA__gdk_window_get_toplevels

#endif
extern __typeof (gdk_window_get_update_area) IA__gdk_window_get_update_area __attribute((visibility("hidden")));
#define gdk_window_get_update_area IA__gdk_window_get_update_area

extern __typeof (gdk_window_get_user_data) IA__gdk_window_get_user_data __attribute((visibility("hidden")));
#define gdk_window_get_user_data IA__gdk_window_get_user_data

extern __typeof (gdk_window_get_window_type) IA__gdk_window_get_window_type __attribute((visibility("hidden")));
#define gdk_window_get_window_type IA__gdk_window_get_window_type

extern __typeof (gdk_window_has_native) IA__gdk_window_has_native __attribute((visibility("hidden")));
#define gdk_window_has_native IA__gdk_window_has_native

extern __typeof (gdk_window_invalidate_maybe_recurse) IA__gdk_window_invalidate_maybe_recurse __attribute((visibility("hidden")));
#define gdk_window_invalidate_maybe_recurse IA__gdk_window_invalidate_maybe_recurse

extern __typeof (gdk_window_invalidate_rect) IA__gdk_window_invalidate_rect __attribute((visibility("hidden")));
#define gdk_window_invalidate_rect IA__gdk_window_invalidate_rect

extern __typeof (gdk_window_invalidate_region) IA__gdk_window_invalidate_region __attribute((visibility("hidden")));
#define gdk_window_invalidate_region IA__gdk_window_invalidate_region

extern __typeof (gdk_window_is_destroyed) IA__gdk_window_is_destroyed __attribute((visibility("hidden")));
#define gdk_window_is_destroyed IA__gdk_window_is_destroyed

extern __typeof (gdk_window_is_input_only) IA__gdk_window_is_input_only __attribute((visibility("hidden")));
#define gdk_window_is_input_only IA__gdk_window_is_input_only

extern __typeof (gdk_window_is_shaped) IA__gdk_window_is_shaped __attribute((visibility("hidden")));
#define gdk_window_is_shaped IA__gdk_window_is_shaped

extern __typeof (gdk_window_is_viewable) IA__gdk_window_is_viewable __attribute((visibility("hidden")));
#define gdk_window_is_viewable IA__gdk_window_is_viewable

extern __typeof (gdk_window_is_visible) IA__gdk_window_is_visible __attribute((visibility("hidden")));
#define gdk_window_is_visible IA__gdk_window_is_visible

extern __typeof (gdk_window_object_get_type) IA__gdk_window_object_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_window_object_get_type IA__gdk_window_object_get_type

extern __typeof (gdk_window_peek_children) IA__gdk_window_peek_children __attribute((visibility("hidden")));
#define gdk_window_peek_children IA__gdk_window_peek_children

extern __typeof (gdk_window_process_all_updates) IA__gdk_window_process_all_updates __attribute((visibility("hidden")));
#define gdk_window_process_all_updates IA__gdk_window_process_all_updates

extern __typeof (gdk_window_process_updates) IA__gdk_window_process_updates __attribute((visibility("hidden")));
#define gdk_window_process_updates IA__gdk_window_process_updates

extern __typeof (gdk_window_redirect_to_drawable) IA__gdk_window_redirect_to_drawable __attribute((visibility("hidden")));
#define gdk_window_redirect_to_drawable IA__gdk_window_redirect_to_drawable

extern __typeof (gdk_window_remove_filter) IA__gdk_window_remove_filter __attribute((visibility("hidden")));
#define gdk_window_remove_filter IA__gdk_window_remove_filter

extern __typeof (gdk_window_remove_redirection) IA__gdk_window_remove_redirection __attribute((visibility("hidden")));
#define gdk_window_remove_redirection IA__gdk_window_remove_redirection

extern __typeof (gdk_window_set_debug_updates) IA__gdk_window_set_debug_updates __attribute((visibility("hidden")));
#define gdk_window_set_debug_updates IA__gdk_window_set_debug_updates

extern __typeof (gdk_window_set_user_data) IA__gdk_window_set_user_data __attribute((visibility("hidden")));
#define gdk_window_set_user_data IA__gdk_window_set_user_data

extern __typeof (gdk_window_thaw_toplevel_updates_libgtk_only) IA__gdk_window_thaw_toplevel_updates_libgtk_only __attribute((visibility("hidden")));
#define gdk_window_thaw_toplevel_updates_libgtk_only IA__gdk_window_thaw_toplevel_updates_libgtk_only

extern __typeof (gdk_window_thaw_updates) IA__gdk_window_thaw_updates __attribute((visibility("hidden")));
#define gdk_window_thaw_updates IA__gdk_window_thaw_updates

extern __typeof (gdk_window_set_composited) IA__gdk_window_set_composited __attribute((visibility("hidden")));
#define gdk_window_set_composited IA__gdk_window_set_composited

extern __typeof (gdk_pointer_grab) IA__gdk_pointer_grab __attribute((visibility("hidden")));
#define gdk_pointer_grab IA__gdk_pointer_grab

extern __typeof (gdk_window_beep) IA__gdk_window_beep __attribute((visibility("hidden")));
#define gdk_window_beep IA__gdk_window_beep

extern __typeof (gdk_window_geometry_changed) IA__gdk_window_geometry_changed __attribute((visibility("hidden")));
#define gdk_window_geometry_changed IA__gdk_window_geometry_changed

extern __typeof (gdk_window_ensure_native) IA__gdk_window_ensure_native __attribute((visibility("hidden")));
#define gdk_window_ensure_native IA__gdk_window_ensure_native

extern __typeof (gdk_window_get_screen) IA__gdk_window_get_screen __attribute((visibility("hidden")));
#define gdk_window_get_screen IA__gdk_window_get_screen

extern __typeof (gdk_window_get_display) IA__gdk_window_get_display __attribute((visibility("hidden")));
#define gdk_window_get_display IA__gdk_window_get_display

extern __typeof (gdk_window_get_visual) IA__gdk_window_get_visual __attribute((visibility("hidden")));
#define gdk_window_get_visual IA__gdk_window_get_visual

extern __typeof (gdk_window_get_width) IA__gdk_window_get_width __attribute((visibility("hidden")));
#define gdk_window_get_width IA__gdk_window_get_width

extern __typeof (gdk_window_get_height) IA__gdk_window_get_height __attribute((visibility("hidden")));
#define gdk_window_get_height IA__gdk_window_get_height

#endif
#endif
#if IN_HEADER(__GDK_WINDOW_H__)
#if IN_FILE(__GDK_OFFSCREEN_WINDOW_C__)
extern __typeof (gdk_offscreen_window_get_pixmap) IA__gdk_offscreen_window_get_pixmap __attribute((visibility("hidden")));
#define gdk_offscreen_window_get_pixmap IA__gdk_offscreen_window_get_pixmap

extern __typeof (gdk_offscreen_window_set_embedder) IA__gdk_offscreen_window_set_embedder __attribute((visibility("hidden")));
#define gdk_offscreen_window_set_embedder IA__gdk_offscreen_window_set_embedder

extern __typeof (gdk_offscreen_window_get_embedder) IA__gdk_offscreen_window_get_embedder __attribute((visibility("hidden")));
#define gdk_offscreen_window_get_embedder IA__gdk_offscreen_window_get_embedder

#endif
#endif
#if IN_HEADER(__GDK_INTERNALS_H__)
#if IN_FILE(__GDK_OFFSCREEN_WINDOW_C__)
extern __typeof (gdk_offscreen_window_get_type) IA__gdk_offscreen_window_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_offscreen_window_get_type IA__gdk_offscreen_window_get_type

#endif
#endif
#if IN_HEADER(__GDK_WINDOW_H__)
#if IN_FILE(__GDK_DND_X11_C__)
extern __typeof (gdk_window_register_dnd) IA__gdk_window_register_dnd __attribute((visibility("hidden")));
#define gdk_window_register_dnd IA__gdk_window_register_dnd

#endif
#endif
#if IN_HEADER(__GDK_WINDOW_H__)
#if IN_FILE(__GDK_WINDOW_X11_C__)
extern __typeof (gdk_window_foreign_new_for_display) IA__gdk_window_foreign_new_for_display __attribute((visibility("hidden")));
#define gdk_window_foreign_new_for_display IA__gdk_window_foreign_new_for_display

extern __typeof (gdk_window_focus) IA__gdk_window_focus __attribute((visibility("hidden")));
#define gdk_window_focus IA__gdk_window_focus

extern __typeof (gdk_window_lookup) IA__gdk_window_lookup __attribute((visibility("hidden")));
#define gdk_window_lookup IA__gdk_window_lookup

extern __typeof (gdk_window_lookup_for_display) IA__gdk_window_lookup_for_display __attribute((visibility("hidden")));
#define gdk_window_lookup_for_display IA__gdk_window_lookup_for_display

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_window_set_hints) IA__gdk_window_set_hints __attribute((visibility("hidden")));
#define gdk_window_set_hints IA__gdk_window_set_hints

#endif
extern __typeof (gdk_window_get_type_hint) IA__gdk_window_get_type_hint __attribute((visibility("hidden")));
#define gdk_window_get_type_hint IA__gdk_window_get_type_hint

extern __typeof (gdk_window_set_type_hint) IA__gdk_window_set_type_hint __attribute((visibility("hidden")));
#define gdk_window_set_type_hint IA__gdk_window_set_type_hint

extern __typeof (gdk_window_set_modal_hint) IA__gdk_window_set_modal_hint __attribute((visibility("hidden")));
#define gdk_window_set_modal_hint IA__gdk_window_set_modal_hint

extern __typeof (gdk_window_set_skip_taskbar_hint) IA__gdk_window_set_skip_taskbar_hint __attribute((visibility("hidden")));
#define gdk_window_set_skip_taskbar_hint IA__gdk_window_set_skip_taskbar_hint

extern __typeof (gdk_window_set_skip_pager_hint) IA__gdk_window_set_skip_pager_hint __attribute((visibility("hidden")));
#define gdk_window_set_skip_pager_hint IA__gdk_window_set_skip_pager_hint

extern __typeof (gdk_window_set_urgency_hint) IA__gdk_window_set_urgency_hint __attribute((visibility("hidden")));
#define gdk_window_set_urgency_hint IA__gdk_window_set_urgency_hint

extern __typeof (gdk_window_set_geometry_hints) IA__gdk_window_set_geometry_hints __attribute((visibility("hidden")));
#define gdk_window_set_geometry_hints IA__gdk_window_set_geometry_hints

extern __typeof (gdk_window_set_title) IA__gdk_window_set_title __attribute((visibility("hidden")));
#define gdk_window_set_title IA__gdk_window_set_title

extern __typeof (gdk_window_set_role) IA__gdk_window_set_role __attribute((visibility("hidden")));
#define gdk_window_set_role IA__gdk_window_set_role

extern __typeof (gdk_window_set_startup_id) IA__gdk_window_set_startup_id __attribute((visibility("hidden")));
#define gdk_window_set_startup_id IA__gdk_window_set_startup_id

extern __typeof (gdk_window_set_transient_for) IA__gdk_window_set_transient_for __attribute((visibility("hidden")));
#define gdk_window_set_transient_for IA__gdk_window_set_transient_for

extern __typeof (gdk_window_get_root_origin) IA__gdk_window_get_root_origin __attribute((visibility("hidden")));
#define gdk_window_get_root_origin IA__gdk_window_get_root_origin

extern __typeof (gdk_window_get_frame_extents) IA__gdk_window_get_frame_extents __attribute((visibility("hidden")));
#define gdk_window_get_frame_extents IA__gdk_window_get_frame_extents

extern __typeof (gdk_window_set_override_redirect) IA__gdk_window_set_override_redirect __attribute((visibility("hidden")));
#define gdk_window_set_override_redirect IA__gdk_window_set_override_redirect

extern __typeof (gdk_window_set_accept_focus) IA__gdk_window_set_accept_focus __attribute((visibility("hidden")));
#define gdk_window_set_accept_focus IA__gdk_window_set_accept_focus

extern __typeof (gdk_window_set_focus_on_map) IA__gdk_window_set_focus_on_map __attribute((visibility("hidden")));
#define gdk_window_set_focus_on_map IA__gdk_window_set_focus_on_map

extern __typeof (gdk_window_set_icon_list) IA__gdk_window_set_icon_list __attribute((visibility("hidden")));
#define gdk_window_set_icon_list IA__gdk_window_set_icon_list

extern __typeof (gdk_window_set_icon) IA__gdk_window_set_icon __attribute((visibility("hidden")));
#define gdk_window_set_icon IA__gdk_window_set_icon

extern __typeof (gdk_window_set_icon_name) IA__gdk_window_set_icon_name __attribute((visibility("hidden")));
#define gdk_window_set_icon_name IA__gdk_window_set_icon_name

extern __typeof (gdk_window_set_opacity) IA__gdk_window_set_opacity __attribute((visibility("hidden")));
#define gdk_window_set_opacity IA__gdk_window_set_opacity

extern __typeof (gdk_window_iconify) IA__gdk_window_iconify __attribute((visibility("hidden")));
#define gdk_window_iconify IA__gdk_window_iconify

extern __typeof (gdk_window_deiconify) IA__gdk_window_deiconify __attribute((visibility("hidden")));
#define gdk_window_deiconify IA__gdk_window_deiconify

extern __typeof (gdk_window_stick) IA__gdk_window_stick __attribute((visibility("hidden")));
#define gdk_window_stick IA__gdk_window_stick

extern __typeof (gdk_window_unstick) IA__gdk_window_unstick __attribute((visibility("hidden")));
#define gdk_window_unstick IA__gdk_window_unstick

extern __typeof (gdk_window_maximize) IA__gdk_window_maximize __attribute((visibility("hidden")));
#define gdk_window_maximize IA__gdk_window_maximize

extern __typeof (gdk_window_unmaximize) IA__gdk_window_unmaximize __attribute((visibility("hidden")));
#define gdk_window_unmaximize IA__gdk_window_unmaximize

extern __typeof (gdk_window_fullscreen) IA__gdk_window_fullscreen __attribute((visibility("hidden")));
#define gdk_window_fullscreen IA__gdk_window_fullscreen

extern __typeof (gdk_window_unfullscreen) IA__gdk_window_unfullscreen __attribute((visibility("hidden")));
#define gdk_window_unfullscreen IA__gdk_window_unfullscreen

extern __typeof (gdk_window_set_keep_above) IA__gdk_window_set_keep_above __attribute((visibility("hidden")));
#define gdk_window_set_keep_above IA__gdk_window_set_keep_above

extern __typeof (gdk_window_set_keep_below) IA__gdk_window_set_keep_below __attribute((visibility("hidden")));
#define gdk_window_set_keep_below IA__gdk_window_set_keep_below

extern __typeof (gdk_window_get_group) IA__gdk_window_get_group __attribute((visibility("hidden")));
#define gdk_window_get_group IA__gdk_window_get_group

extern __typeof (gdk_window_set_group) IA__gdk_window_set_group __attribute((visibility("hidden")));
#define gdk_window_set_group IA__gdk_window_set_group

extern __typeof (gdk_window_get_decorations) IA__gdk_window_get_decorations __attribute((visibility("hidden")));
#define gdk_window_get_decorations IA__gdk_window_get_decorations

extern __typeof (gdk_window_set_decorations) IA__gdk_window_set_decorations __attribute((visibility("hidden")));
#define gdk_window_set_decorations IA__gdk_window_set_decorations

extern __typeof (gdk_window_set_functions) IA__gdk_window_set_functions __attribute((visibility("hidden")));
#define gdk_window_set_functions IA__gdk_window_set_functions

extern __typeof (gdk_window_begin_move_drag) IA__gdk_window_begin_move_drag __attribute((visibility("hidden")));
#define gdk_window_begin_move_drag IA__gdk_window_begin_move_drag

extern __typeof (gdk_window_begin_resize_drag) IA__gdk_window_begin_resize_drag __attribute((visibility("hidden")));
#define gdk_window_begin_resize_drag IA__gdk_window_begin_resize_drag

extern __typeof (gdk_window_enable_synchronized_configure) IA__gdk_window_enable_synchronized_configure __attribute((visibility("hidden")));
#define gdk_window_enable_synchronized_configure IA__gdk_window_enable_synchronized_configure

extern __typeof (gdk_window_configure_finished) IA__gdk_window_configure_finished __attribute((visibility("hidden")));
#define gdk_window_configure_finished IA__gdk_window_configure_finished

#endif
#endif
#if IN_HEADER(__GDK_IMAGE_H__)
#if IN_FILE(__GDK_IMAGE_C__)
extern __typeof (gdk_image_get_bits_per_pixel) IA__gdk_image_get_bits_per_pixel __attribute((visibility("hidden")));
#define gdk_image_get_bits_per_pixel IA__gdk_image_get_bits_per_pixel

extern __typeof (gdk_image_get_bytes_per_pixel) IA__gdk_image_get_bytes_per_pixel __attribute((visibility("hidden")));
#define gdk_image_get_bytes_per_pixel IA__gdk_image_get_bytes_per_pixel

extern __typeof (gdk_image_get_bytes_per_line) IA__gdk_image_get_bytes_per_line __attribute((visibility("hidden")));
#define gdk_image_get_bytes_per_line IA__gdk_image_get_bytes_per_line

extern __typeof (gdk_image_get_byte_order) IA__gdk_image_get_byte_order __attribute((visibility("hidden")));
#define gdk_image_get_byte_order IA__gdk_image_get_byte_order

extern __typeof (gdk_image_get_depth) IA__gdk_image_get_depth __attribute((visibility("hidden")));
#define gdk_image_get_depth IA__gdk_image_get_depth

extern __typeof (gdk_image_get_height) IA__gdk_image_get_height __attribute((visibility("hidden")));
#define gdk_image_get_height IA__gdk_image_get_height

extern __typeof (gdk_image_get_image_type) IA__gdk_image_get_image_type __attribute((visibility("hidden")));
#define gdk_image_get_image_type IA__gdk_image_get_image_type

extern __typeof (gdk_image_get_visual) IA__gdk_image_get_visual __attribute((visibility("hidden")));
#define gdk_image_get_visual IA__gdk_image_get_visual

extern __typeof (gdk_image_get_width) IA__gdk_image_get_width __attribute((visibility("hidden")));
#define gdk_image_get_width IA__gdk_image_get_width

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_image_ref) IA__gdk_image_ref __attribute((visibility("hidden")));
#define gdk_image_ref IA__gdk_image_ref

extern __typeof (gdk_image_unref) IA__gdk_image_unref __attribute((visibility("hidden")));
#define gdk_image_unref IA__gdk_image_unref

extern __typeof (gdk_image_get) IA__gdk_image_get __attribute((visibility("hidden")));
#define gdk_image_get IA__gdk_image_get

#endif
extern __typeof (gdk_image_get_pixels) IA__gdk_image_get_pixels __attribute((visibility("hidden")));
#define gdk_image_get_pixels IA__gdk_image_get_pixels

extern __typeof (gdk_image_set_colormap) IA__gdk_image_set_colormap __attribute((visibility("hidden")));
#define gdk_image_set_colormap IA__gdk_image_set_colormap

extern __typeof (gdk_image_get_colormap) IA__gdk_image_get_colormap __attribute((visibility("hidden")));
#define gdk_image_get_colormap IA__gdk_image_get_colormap

extern __typeof (gdk_image_new) IA__gdk_image_new __attribute((visibility("hidden")));
#define gdk_image_new IA__gdk_image_new

#endif
#endif
#if IN_HEADER(__GDK_IMAGE_H__)
#if IN_FILE(__GDK_IMAGE_X11_C__)
#ifdef GDK_ENABLE_BROKEN
extern __typeof (gdk_image_new_bitmap) IA__gdk_image_new_bitmap __attribute((visibility("hidden")));
#define gdk_image_new_bitmap IA__gdk_image_new_bitmap

#endif
extern __typeof (gdk_image_get_pixel) IA__gdk_image_get_pixel __attribute((visibility("hidden")));
#define gdk_image_get_pixel IA__gdk_image_get_pixel

extern __typeof (gdk_image_put_pixel) IA__gdk_image_put_pixel __attribute((visibility("hidden")));
#define gdk_image_put_pixel IA__gdk_image_put_pixel

extern __typeof (gdk_image_get_type) IA__gdk_image_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_image_get_type IA__gdk_image_get_type

#endif
#endif
#if IN_HEADER(__GDK_KEYS_H__)
#if IN_FILE(__GDK_KEYS_C__)
extern __typeof (gdk_keymap_get_default) IA__gdk_keymap_get_default __attribute((visibility("hidden")));
#define gdk_keymap_get_default IA__gdk_keymap_get_default

extern __typeof (gdk_keymap_get_type) IA__gdk_keymap_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_keymap_get_type IA__gdk_keymap_get_type

extern __typeof (gdk_keyval_is_lower) IA__gdk_keyval_is_lower __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_keyval_is_lower IA__gdk_keyval_is_lower

extern __typeof (gdk_keyval_is_upper) IA__gdk_keyval_is_upper __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_keyval_is_upper IA__gdk_keyval_is_upper

extern __typeof (gdk_keyval_to_lower) IA__gdk_keyval_to_lower __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_keyval_to_lower IA__gdk_keyval_to_lower

extern __typeof (gdk_keyval_to_upper) IA__gdk_keyval_to_upper __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_keyval_to_upper IA__gdk_keyval_to_upper

#endif
#endif
#if IN_HEADER(__GDK_KEYS_H__)
#if IN_FILE(__GDK_KEYUNI_C__)
extern __typeof (gdk_keyval_to_unicode) IA__gdk_keyval_to_unicode __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_keyval_to_unicode IA__gdk_keyval_to_unicode

extern __typeof (gdk_unicode_to_keyval) IA__gdk_unicode_to_keyval __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_unicode_to_keyval IA__gdk_unicode_to_keyval

#endif
#endif
#if IN_HEADER(__GDK_KEYS_H__)
#if IN_FILE(__GDK_KEYS_X11_C__)
extern __typeof (gdk_keymap_get_direction) IA__gdk_keymap_get_direction __attribute((visibility("hidden")));
#define gdk_keymap_get_direction IA__gdk_keymap_get_direction

extern __typeof (gdk_keymap_get_entries_for_keycode) IA__gdk_keymap_get_entries_for_keycode __attribute((visibility("hidden")));
#define gdk_keymap_get_entries_for_keycode IA__gdk_keymap_get_entries_for_keycode

extern __typeof (gdk_keymap_get_entries_for_keyval) IA__gdk_keymap_get_entries_for_keyval __attribute((visibility("hidden")));
#define gdk_keymap_get_entries_for_keyval IA__gdk_keymap_get_entries_for_keyval

extern __typeof (gdk_keymap_get_for_display) IA__gdk_keymap_get_for_display __attribute((visibility("hidden")));
#define gdk_keymap_get_for_display IA__gdk_keymap_get_for_display

extern __typeof (gdk_keymap_have_bidi_layouts) IA__gdk_keymap_have_bidi_layouts __attribute((visibility("hidden")));
#define gdk_keymap_have_bidi_layouts IA__gdk_keymap_have_bidi_layouts

extern __typeof (gdk_keymap_get_caps_lock_state) IA__gdk_keymap_get_caps_lock_state __attribute((visibility("hidden")));
#define gdk_keymap_get_caps_lock_state IA__gdk_keymap_get_caps_lock_state

extern __typeof (gdk_keymap_lookup_key) IA__gdk_keymap_lookup_key __attribute((visibility("hidden")));
#define gdk_keymap_lookup_key IA__gdk_keymap_lookup_key

extern __typeof (gdk_keymap_translate_keyboard_state) IA__gdk_keymap_translate_keyboard_state __attribute((visibility("hidden")));
#define gdk_keymap_translate_keyboard_state IA__gdk_keymap_translate_keyboard_state

extern __typeof (gdk_keymap_add_virtual_modifiers) IA__gdk_keymap_add_virtual_modifiers __attribute((visibility("hidden")));
#define gdk_keymap_add_virtual_modifiers IA__gdk_keymap_add_virtual_modifiers

extern __typeof (gdk_keymap_map_virtual_modifiers) IA__gdk_keymap_map_virtual_modifiers __attribute((visibility("hidden")));
#define gdk_keymap_map_virtual_modifiers IA__gdk_keymap_map_virtual_modifiers

extern __typeof (gdk_keyval_convert_case) IA__gdk_keyval_convert_case __attribute((visibility("hidden")));
#define gdk_keyval_convert_case IA__gdk_keyval_convert_case

extern __typeof (gdk_keyval_from_name) IA__gdk_keyval_from_name __attribute((visibility("hidden")));
#define gdk_keyval_from_name IA__gdk_keyval_from_name

extern __typeof (gdk_keyval_name) IA__gdk_keyval_name __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_keyval_name IA__gdk_keyval_name

#endif
#endif
#if IN_HEADER(__GDK_KEYS_H__)
#if IN_FILE(__GDK_KEYS_DIRECTFB_C__)
extern __typeof (gdk_keymap_get_direction) IA__gdk_keymap_get_direction __attribute((visibility("hidden")));
#define gdk_keymap_get_direction IA__gdk_keymap_get_direction

extern __typeof (gdk_keymap_get_entries_for_keycode) IA__gdk_keymap_get_entries_for_keycode __attribute((visibility("hidden")));
#define gdk_keymap_get_entries_for_keycode IA__gdk_keymap_get_entries_for_keycode

extern __typeof (gdk_keymap_get_entries_for_keyval) IA__gdk_keymap_get_entries_for_keyval __attribute((visibility("hidden")));
#define gdk_keymap_get_entries_for_keyval IA__gdk_keymap_get_entries_for_keyval

extern __typeof (gdk_keymap_get_for_display) IA__gdk_keymap_get_for_display __attribute((visibility("hidden")));
#define gdk_keymap_get_for_display IA__gdk_keymap_get_for_display

extern __typeof (gdk_keymap_get_caps_lock_state) IA__gdk_keymap_get_caps_lock_state __attribute((visibility("hidden")));
#define gdk_keymap_get_caps_lock_state IA__gdk_keymap_get_caps_lock_state

extern __typeof (gdk_keymap_lookup_key) IA__gdk_keymap_lookup_key __attribute((visibility("hidden")));
#define gdk_keymap_lookup_key IA__gdk_keymap_lookup_key

extern __typeof (gdk_keymap_translate_keyboard_state) IA__gdk_keymap_translate_keyboard_state __attribute((visibility("hidden")));
#define gdk_keymap_translate_keyboard_state IA__gdk_keymap_translate_keyboard_state

extern __typeof (gdk_keymap_add_virtual_modifiers) IA__gdk_keymap_add_virtual_modifiers __attribute((visibility("hidden")));
#define gdk_keymap_add_virtual_modifiers IA__gdk_keymap_add_virtual_modifiers

extern __typeof (gdk_keymap_map_virtual_modifiers) IA__gdk_keymap_map_virtual_modifiers __attribute((visibility("hidden")));
#define gdk_keymap_map_virtual_modifiers IA__gdk_keymap_map_virtual_modifiers

extern __typeof (gdk_keyval_from_name) IA__gdk_keyval_from_name __attribute((visibility("hidden")));
#define gdk_keyval_from_name IA__gdk_keyval_from_name

extern __typeof (gdk_keyval_name) IA__gdk_keyval_name __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_keyval_name IA__gdk_keyval_name

#endif
#endif
#if IN_HEADER(__GDK_VISUAL_H__)
#if IN_FILE(__GDK_VISUAL_C__)
extern __typeof (gdk_list_visuals) IA__gdk_list_visuals __attribute((visibility("hidden")));
#define gdk_list_visuals IA__gdk_list_visuals

extern __typeof (gdk_visual_get_bits_per_rgb) IA__gdk_visual_get_bits_per_rgb __attribute((visibility("hidden")));
#define gdk_visual_get_bits_per_rgb IA__gdk_visual_get_bits_per_rgb

extern __typeof (gdk_visual_get_blue_pixel_details) IA__gdk_visual_get_blue_pixel_details __attribute((visibility("hidden")));
#define gdk_visual_get_blue_pixel_details IA__gdk_visual_get_blue_pixel_details

extern __typeof (gdk_visual_get_byte_order) IA__gdk_visual_get_byte_order __attribute((visibility("hidden")));
#define gdk_visual_get_byte_order IA__gdk_visual_get_byte_order

extern __typeof (gdk_visual_get_colormap_size) IA__gdk_visual_get_colormap_size __attribute((visibility("hidden")));
#define gdk_visual_get_colormap_size IA__gdk_visual_get_colormap_size

extern __typeof (gdk_visual_get_depth) IA__gdk_visual_get_depth __attribute((visibility("hidden")));
#define gdk_visual_get_depth IA__gdk_visual_get_depth

extern __typeof (gdk_visual_get_green_pixel_details) IA__gdk_visual_get_green_pixel_details __attribute((visibility("hidden")));
#define gdk_visual_get_green_pixel_details IA__gdk_visual_get_green_pixel_details

extern __typeof (gdk_visual_get_red_pixel_details) IA__gdk_visual_get_red_pixel_details __attribute((visibility("hidden")));
#define gdk_visual_get_red_pixel_details IA__gdk_visual_get_red_pixel_details

extern __typeof (gdk_visual_get_system) IA__gdk_visual_get_system __attribute((visibility("hidden")));
#define gdk_visual_get_system IA__gdk_visual_get_system

extern __typeof (gdk_visual_get_visual_type) IA__gdk_visual_get_visual_type __attribute((visibility("hidden")));
#define gdk_visual_get_visual_type IA__gdk_visual_get_visual_type

#endif
#endif
#if IN_HEADER(__GDK_VISUAL_H__)
#if IN_FILE(__GDK_VISUAL_X11_C__)
extern __typeof (gdk_query_depths) IA__gdk_query_depths __attribute((visibility("hidden")));
#define gdk_query_depths IA__gdk_query_depths

extern __typeof (gdk_query_visual_types) IA__gdk_query_visual_types __attribute((visibility("hidden")));
#define gdk_query_visual_types IA__gdk_query_visual_types

extern __typeof (gdk_visual_get_best) IA__gdk_visual_get_best __attribute((visibility("hidden")));
#define gdk_visual_get_best IA__gdk_visual_get_best

extern __typeof (gdk_visual_get_best_depth) IA__gdk_visual_get_best_depth __attribute((visibility("hidden")));
#define gdk_visual_get_best_depth IA__gdk_visual_get_best_depth

extern __typeof (gdk_visual_get_best_type) IA__gdk_visual_get_best_type __attribute((visibility("hidden")));
#define gdk_visual_get_best_type IA__gdk_visual_get_best_type

extern __typeof (gdk_visual_get_best_with_both) IA__gdk_visual_get_best_with_both __attribute((visibility("hidden")));
#define gdk_visual_get_best_with_both IA__gdk_visual_get_best_with_both

extern __typeof (gdk_visual_get_best_with_depth) IA__gdk_visual_get_best_with_depth __attribute((visibility("hidden")));
#define gdk_visual_get_best_with_depth IA__gdk_visual_get_best_with_depth

extern __typeof (gdk_visual_get_best_with_type) IA__gdk_visual_get_best_with_type __attribute((visibility("hidden")));
#define gdk_visual_get_best_with_type IA__gdk_visual_get_best_with_type

extern __typeof (gdk_visual_get_screen) IA__gdk_visual_get_screen __attribute((visibility("hidden")));
#define gdk_visual_get_screen IA__gdk_visual_get_screen

extern __typeof (gdk_visual_get_type) IA__gdk_visual_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_visual_get_type IA__gdk_visual_get_type

#endif
#endif
#if IN_HEADER(__GDK_X_H__)
#if IN_FILE(__GDK_EVENTS_X11_C__)
#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_net_wm_supports) IA__gdk_net_wm_supports __attribute((visibility("hidden")));
#define gdk_net_wm_supports IA__gdk_net_wm_supports

#endif
#endif
#endif
#if IN_HEADER(__GDK_PANGO_H__)
#if IN_FILE(__GDK_PANGO_C__)
extern __typeof (gdk_pango_attr_emboss_color_new) IA__gdk_pango_attr_emboss_color_new __attribute((visibility("hidden")));
#define gdk_pango_attr_emboss_color_new IA__gdk_pango_attr_emboss_color_new

extern __typeof (gdk_pango_attr_embossed_new) IA__gdk_pango_attr_embossed_new __attribute((visibility("hidden")));
#define gdk_pango_attr_embossed_new IA__gdk_pango_attr_embossed_new

extern __typeof (gdk_pango_attr_stipple_new) IA__gdk_pango_attr_stipple_new __attribute((visibility("hidden")));
#define gdk_pango_attr_stipple_new IA__gdk_pango_attr_stipple_new

extern __typeof (gdk_pango_context_get) IA__gdk_pango_context_get __attribute((visibility("hidden")));
#define gdk_pango_context_get IA__gdk_pango_context_get

extern __typeof (gdk_pango_context_get_for_screen) IA__gdk_pango_context_get_for_screen __attribute((visibility("hidden")));
#define gdk_pango_context_get_for_screen IA__gdk_pango_context_get_for_screen

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_pango_context_set_colormap) IA__gdk_pango_context_set_colormap __attribute((visibility("hidden")));
#define gdk_pango_context_set_colormap IA__gdk_pango_context_set_colormap

#endif
extern __typeof (gdk_pango_layout_get_clip_region) IA__gdk_pango_layout_get_clip_region __attribute((visibility("hidden")));
#define gdk_pango_layout_get_clip_region IA__gdk_pango_layout_get_clip_region

extern __typeof (gdk_pango_layout_line_get_clip_region) IA__gdk_pango_layout_line_get_clip_region __attribute((visibility("hidden")));
#define gdk_pango_layout_line_get_clip_region IA__gdk_pango_layout_line_get_clip_region

extern __typeof (gdk_pango_renderer_get_default) IA__gdk_pango_renderer_get_default __attribute((visibility("hidden")));
#define gdk_pango_renderer_get_default IA__gdk_pango_renderer_get_default

extern __typeof (gdk_pango_renderer_get_type) IA__gdk_pango_renderer_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_pango_renderer_get_type IA__gdk_pango_renderer_get_type

extern __typeof (gdk_pango_renderer_new) IA__gdk_pango_renderer_new __attribute((visibility("hidden")));
#define gdk_pango_renderer_new IA__gdk_pango_renderer_new

extern __typeof (gdk_pango_renderer_set_drawable) IA__gdk_pango_renderer_set_drawable __attribute((visibility("hidden")));
#define gdk_pango_renderer_set_drawable IA__gdk_pango_renderer_set_drawable

extern __typeof (gdk_pango_renderer_set_gc) IA__gdk_pango_renderer_set_gc __attribute((visibility("hidden")));
#define gdk_pango_renderer_set_gc IA__gdk_pango_renderer_set_gc

extern __typeof (gdk_pango_renderer_set_override_color) IA__gdk_pango_renderer_set_override_color __attribute((visibility("hidden")));
#define gdk_pango_renderer_set_override_color IA__gdk_pango_renderer_set_override_color

extern __typeof (gdk_pango_renderer_set_stipple) IA__gdk_pango_renderer_set_stipple __attribute((visibility("hidden")));
#define gdk_pango_renderer_set_stipple IA__gdk_pango_renderer_set_stipple

#endif
#endif
#if IN_HEADER(__GDK_PIXBUF_H__)
#if IN_FILE(__GDK_PIXBUF_DRAWABLE_C__)
extern __typeof (gdk_pixbuf_get_from_drawable) IA__gdk_pixbuf_get_from_drawable __attribute((visibility("hidden")));
#define gdk_pixbuf_get_from_drawable IA__gdk_pixbuf_get_from_drawable

extern __typeof (gdk_pixbuf_get_from_image) IA__gdk_pixbuf_get_from_image __attribute((visibility("hidden")));
#define gdk_pixbuf_get_from_image IA__gdk_pixbuf_get_from_image

#endif
#endif
#if IN_HEADER(__GDK_PIXBUF_H__)
#if IN_FILE(__GDK_PIXBUF_RENDER_C__)
extern __typeof (gdk_pixbuf_render_pixmap_and_mask) IA__gdk_pixbuf_render_pixmap_and_mask __attribute((visibility("hidden")));
#define gdk_pixbuf_render_pixmap_and_mask IA__gdk_pixbuf_render_pixmap_and_mask

extern __typeof (gdk_pixbuf_render_pixmap_and_mask_for_colormap) IA__gdk_pixbuf_render_pixmap_and_mask_for_colormap __attribute((visibility("hidden")));
#define gdk_pixbuf_render_pixmap_and_mask_for_colormap IA__gdk_pixbuf_render_pixmap_and_mask_for_colormap

extern __typeof (gdk_pixbuf_render_threshold_alpha) IA__gdk_pixbuf_render_threshold_alpha __attribute((visibility("hidden")));
#define gdk_pixbuf_render_threshold_alpha IA__gdk_pixbuf_render_threshold_alpha

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_pixbuf_render_to_drawable) IA__gdk_pixbuf_render_to_drawable __attribute((visibility("hidden")));
#define gdk_pixbuf_render_to_drawable IA__gdk_pixbuf_render_to_drawable

extern __typeof (gdk_pixbuf_render_to_drawable_alpha) IA__gdk_pixbuf_render_to_drawable_alpha __attribute((visibility("hidden")));
#define gdk_pixbuf_render_to_drawable_alpha IA__gdk_pixbuf_render_to_drawable_alpha

#endif
#endif
#endif
#if IN_HEADER(__GDK_PIXMAP_H__)
#if IN_FILE(__GDK_PIXMAP_C__)
extern __typeof (gdk_bitmap_create_from_data) IA__gdk_bitmap_create_from_data __attribute((visibility("hidden")));
#define gdk_bitmap_create_from_data IA__gdk_bitmap_create_from_data

extern __typeof (gdk_pixmap_colormap_create_from_xpm) IA__gdk_pixmap_colormap_create_from_xpm __attribute((visibility("hidden")));
#define gdk_pixmap_colormap_create_from_xpm IA__gdk_pixmap_colormap_create_from_xpm

extern __typeof (gdk_pixmap_create_from_data) IA__gdk_pixmap_create_from_data __attribute((visibility("hidden")));
#define gdk_pixmap_create_from_data IA__gdk_pixmap_create_from_data

extern __typeof (gdk_pixmap_create_from_xpm) IA__gdk_pixmap_create_from_xpm __attribute((visibility("hidden")));
#define gdk_pixmap_create_from_xpm IA__gdk_pixmap_create_from_xpm

extern __typeof (gdk_pixmap_colormap_create_from_xpm_d) IA__gdk_pixmap_colormap_create_from_xpm_d __attribute((visibility("hidden")));
#define gdk_pixmap_colormap_create_from_xpm_d IA__gdk_pixmap_colormap_create_from_xpm_d

extern __typeof (gdk_pixmap_create_from_xpm_d) IA__gdk_pixmap_create_from_xpm_d __attribute((visibility("hidden")));
#define gdk_pixmap_create_from_xpm_d IA__gdk_pixmap_create_from_xpm_d

extern __typeof (gdk_pixmap_get_size) IA__gdk_pixmap_get_size __attribute((visibility("hidden")));
#define gdk_pixmap_get_size IA__gdk_pixmap_get_size

extern __typeof (gdk_pixmap_get_type) IA__gdk_pixmap_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_pixmap_get_type IA__gdk_pixmap_get_type

extern __typeof (gdk_pixmap_new) IA__gdk_pixmap_new __attribute((visibility("hidden")));
#define gdk_pixmap_new IA__gdk_pixmap_new

#endif
#endif
#if IN_HEADER(__GDK_PIXMAP_H__)
#if IN_FILE(__GDK_PIXMAP_X11_C__)
extern __typeof (gdk_pixmap_foreign_new) IA__gdk_pixmap_foreign_new __attribute((visibility("hidden")));
#define gdk_pixmap_foreign_new IA__gdk_pixmap_foreign_new

extern __typeof (gdk_pixmap_foreign_new_for_display) IA__gdk_pixmap_foreign_new_for_display __attribute((visibility("hidden")));
#define gdk_pixmap_foreign_new_for_display IA__gdk_pixmap_foreign_new_for_display

extern __typeof (gdk_pixmap_foreign_new_for_screen) IA__gdk_pixmap_foreign_new_for_screen __attribute((visibility("hidden")));
#define gdk_pixmap_foreign_new_for_screen IA__gdk_pixmap_foreign_new_for_screen

extern __typeof (gdk_pixmap_lookup) IA__gdk_pixmap_lookup __attribute((visibility("hidden")));
#define gdk_pixmap_lookup IA__gdk_pixmap_lookup

extern __typeof (gdk_pixmap_lookup_for_display) IA__gdk_pixmap_lookup_for_display __attribute((visibility("hidden")));
#define gdk_pixmap_lookup_for_display IA__gdk_pixmap_lookup_for_display

#endif
#endif
#if IN_HEADER(__GDK_REGION_H__)
#if IN_FILE(__GDK_REGION_GENERIC_C__)
extern __typeof (gdk_region_copy) IA__gdk_region_copy __attribute((visibility("hidden")));
#define gdk_region_copy IA__gdk_region_copy

extern __typeof (gdk_region_destroy) IA__gdk_region_destroy __attribute((visibility("hidden")));
#define gdk_region_destroy IA__gdk_region_destroy

extern __typeof (gdk_region_empty) IA__gdk_region_empty __attribute((visibility("hidden")));
#define gdk_region_empty IA__gdk_region_empty

extern __typeof (gdk_region_equal) IA__gdk_region_equal __attribute((visibility("hidden")));
#define gdk_region_equal IA__gdk_region_equal

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_region_rect_equal) IA__gdk_region_rect_equal __attribute((visibility("hidden")));
#define gdk_region_rect_equal IA__gdk_region_rect_equal

#endif
extern __typeof (gdk_region_get_clipbox) IA__gdk_region_get_clipbox __attribute((visibility("hidden")));
#define gdk_region_get_clipbox IA__gdk_region_get_clipbox

extern __typeof (gdk_region_get_rectangles) IA__gdk_region_get_rectangles __attribute((visibility("hidden")));
#define gdk_region_get_rectangles IA__gdk_region_get_rectangles

extern __typeof (gdk_region_intersect) IA__gdk_region_intersect __attribute((visibility("hidden")));
#define gdk_region_intersect IA__gdk_region_intersect

extern __typeof (gdk_region_new) IA__gdk_region_new __attribute((visibility("hidden")));
#define gdk_region_new IA__gdk_region_new

extern __typeof (gdk_region_offset) IA__gdk_region_offset __attribute((visibility("hidden")));
#define gdk_region_offset IA__gdk_region_offset

extern __typeof (gdk_region_point_in) IA__gdk_region_point_in __attribute((visibility("hidden")));
#define gdk_region_point_in IA__gdk_region_point_in

extern __typeof (gdk_region_rectangle) IA__gdk_region_rectangle __attribute((visibility("hidden")));
#define gdk_region_rectangle IA__gdk_region_rectangle

extern __typeof (gdk_region_rect_in) IA__gdk_region_rect_in __attribute((visibility("hidden")));
#define gdk_region_rect_in IA__gdk_region_rect_in

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_region_shrink) IA__gdk_region_shrink __attribute((visibility("hidden")));
#define gdk_region_shrink IA__gdk_region_shrink

extern __typeof (gdk_region_spans_intersect_foreach) IA__gdk_region_spans_intersect_foreach __attribute((visibility("hidden")));
#define gdk_region_spans_intersect_foreach IA__gdk_region_spans_intersect_foreach

#endif
extern __typeof (gdk_region_subtract) IA__gdk_region_subtract __attribute((visibility("hidden")));
#define gdk_region_subtract IA__gdk_region_subtract

extern __typeof (gdk_region_union) IA__gdk_region_union __attribute((visibility("hidden")));
#define gdk_region_union IA__gdk_region_union

extern __typeof (gdk_region_union_with_rect) IA__gdk_region_union_with_rect __attribute((visibility("hidden")));
#define gdk_region_union_with_rect IA__gdk_region_union_with_rect

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_region_xor) IA__gdk_region_xor __attribute((visibility("hidden")));
#define gdk_region_xor IA__gdk_region_xor

#endif
#endif
#endif
#if IN_HEADER(__GDK_REGION_H__)
#if IN_FILE(__GDK_POLYREG_GENERIC_C__)
#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_region_polygon) IA__gdk_region_polygon __attribute((visibility("hidden")));
#define gdk_region_polygon IA__gdk_region_polygon

#endif
#endif
#endif
#if IN_HEADER(__GDK_RGB_H__)
#if IN_FILE(__GDK_RGB_C__)
extern __typeof (gdk_rgb_cmap_free) IA__gdk_rgb_cmap_free __attribute((visibility("hidden")));
#define gdk_rgb_cmap_free IA__gdk_rgb_cmap_free

extern __typeof (gdk_rgb_cmap_new) IA__gdk_rgb_cmap_new __attribute((visibility("hidden")));
#define gdk_rgb_cmap_new IA__gdk_rgb_cmap_new

extern __typeof (gdk_rgb_colormap_ditherable) IA__gdk_rgb_colormap_ditherable __attribute((visibility("hidden")));
#define gdk_rgb_colormap_ditherable IA__gdk_rgb_colormap_ditherable

extern __typeof (gdk_rgb_ditherable) IA__gdk_rgb_ditherable __attribute((visibility("hidden")));
#define gdk_rgb_ditherable IA__gdk_rgb_ditherable

extern __typeof (gdk_rgb_find_color) IA__gdk_rgb_find_color __attribute((visibility("hidden")));
#define gdk_rgb_find_color IA__gdk_rgb_find_color

extern __typeof (gdk_rgb_get_colormap) IA__gdk_rgb_get_colormap __attribute((visibility("hidden")));
#define gdk_rgb_get_colormap IA__gdk_rgb_get_colormap

extern __typeof (gdk_rgb_get_visual) IA__gdk_rgb_get_visual __attribute((visibility("hidden")));
#define gdk_rgb_get_visual IA__gdk_rgb_get_visual

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_rgb_init) IA__gdk_rgb_init __attribute((visibility("hidden")));
#define gdk_rgb_init IA__gdk_rgb_init

extern __typeof (gdk_rgb_xpixel_from_rgb) IA__gdk_rgb_xpixel_from_rgb __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_rgb_xpixel_from_rgb IA__gdk_rgb_xpixel_from_rgb

extern __typeof (gdk_rgb_gc_set_background) IA__gdk_rgb_gc_set_background __attribute((visibility("hidden")));
#define gdk_rgb_gc_set_background IA__gdk_rgb_gc_set_background

extern __typeof (gdk_rgb_gc_set_foreground) IA__gdk_rgb_gc_set_foreground __attribute((visibility("hidden")));
#define gdk_rgb_gc_set_foreground IA__gdk_rgb_gc_set_foreground

#endif
extern __typeof (gdk_rgb_set_install) IA__gdk_rgb_set_install __attribute((visibility("hidden")));
#define gdk_rgb_set_install IA__gdk_rgb_set_install

extern __typeof (gdk_rgb_set_min_colors) IA__gdk_rgb_set_min_colors __attribute((visibility("hidden")));
#define gdk_rgb_set_min_colors IA__gdk_rgb_set_min_colors

extern __typeof (gdk_rgb_set_verbose) IA__gdk_rgb_set_verbose __attribute((visibility("hidden")));
#define gdk_rgb_set_verbose IA__gdk_rgb_set_verbose

extern __typeof (gdk_draw_gray_image) IA__gdk_draw_gray_image __attribute((visibility("hidden")));
#define gdk_draw_gray_image IA__gdk_draw_gray_image

extern __typeof (gdk_draw_indexed_image) IA__gdk_draw_indexed_image __attribute((visibility("hidden")));
#define gdk_draw_indexed_image IA__gdk_draw_indexed_image

extern __typeof (gdk_draw_rgb_32_image) IA__gdk_draw_rgb_32_image __attribute((visibility("hidden")));
#define gdk_draw_rgb_32_image IA__gdk_draw_rgb_32_image

extern __typeof (gdk_draw_rgb_32_image_dithalign) IA__gdk_draw_rgb_32_image_dithalign __attribute((visibility("hidden")));
#define gdk_draw_rgb_32_image_dithalign IA__gdk_draw_rgb_32_image_dithalign

extern __typeof (gdk_draw_rgb_image) IA__gdk_draw_rgb_image __attribute((visibility("hidden")));
#define gdk_draw_rgb_image IA__gdk_draw_rgb_image

extern __typeof (gdk_draw_rgb_image_dithalign) IA__gdk_draw_rgb_image_dithalign __attribute((visibility("hidden")));
#define gdk_draw_rgb_image_dithalign IA__gdk_draw_rgb_image_dithalign

#endif
#endif
#if IN_HEADER(__GDK_SCREEN_H__)
#if IN_FILE(__GDK_SCREEN_C__)
extern __typeof (gdk_screen_get_type) IA__gdk_screen_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_screen_get_type IA__gdk_screen_get_type

extern __typeof (gdk_screen_get_monitor_at_point) IA__gdk_screen_get_monitor_at_point __attribute((visibility("hidden")));
#define gdk_screen_get_monitor_at_point IA__gdk_screen_get_monitor_at_point

extern __typeof (gdk_screen_get_monitor_at_window) IA__gdk_screen_get_monitor_at_window __attribute((visibility("hidden")));
#define gdk_screen_get_monitor_at_window IA__gdk_screen_get_monitor_at_window

extern __typeof (gdk_screen_set_font_options) IA__gdk_screen_set_font_options __attribute((visibility("hidden")));
#define gdk_screen_set_font_options IA__gdk_screen_set_font_options

extern __typeof (gdk_screen_get_font_options) IA__gdk_screen_get_font_options __attribute((visibility("hidden")));
#define gdk_screen_get_font_options IA__gdk_screen_get_font_options

extern __typeof (gdk_screen_set_resolution) IA__gdk_screen_set_resolution __attribute((visibility("hidden")));
#define gdk_screen_set_resolution IA__gdk_screen_set_resolution

extern __typeof (gdk_screen_get_resolution) IA__gdk_screen_get_resolution __attribute((visibility("hidden")));
#define gdk_screen_get_resolution IA__gdk_screen_get_resolution

#endif
#endif
#if IN_HEADER(__GDK_SCREEN_H__)
#if IN_FILE(__GDK_DISPLAY_MANAGER_C__)
extern __typeof (gdk_screen_get_default) IA__gdk_screen_get_default __attribute((visibility("hidden")));
#define gdk_screen_get_default IA__gdk_screen_get_default

#endif
#endif
#if IN_HEADER(__GDK_SCREEN_H__)
#if IN_FILE(__GDK_RGB_C__)
extern __typeof (gdk_screen_get_rgb_colormap) IA__gdk_screen_get_rgb_colormap __attribute((visibility("hidden")));
#define gdk_screen_get_rgb_colormap IA__gdk_screen_get_rgb_colormap

extern __typeof (gdk_screen_get_rgb_visual) IA__gdk_screen_get_rgb_visual __attribute((visibility("hidden")));
#define gdk_screen_get_rgb_visual IA__gdk_screen_get_rgb_visual

#endif
#endif
#if IN_HEADER(__GDK_SCREEN_H__)
#if IN_FILE(__GDK_EVENTS_X11_C__)
extern __typeof (gdk_screen_get_setting) IA__gdk_screen_get_setting __attribute((visibility("hidden")));
#define gdk_screen_get_setting IA__gdk_screen_get_setting

extern __typeof (gdk_screen_broadcast_client_message) IA__gdk_screen_broadcast_client_message __attribute((visibility("hidden")));
#define gdk_screen_broadcast_client_message IA__gdk_screen_broadcast_client_message

#endif
#endif
#if IN_HEADER(__GDK_SCREEN_H__)
#if IN_FILE(__GDK_VISUAL_X11_C__)
extern __typeof (gdk_screen_get_system_visual) IA__gdk_screen_get_system_visual __attribute((visibility("hidden")));
#define gdk_screen_get_system_visual IA__gdk_screen_get_system_visual

extern __typeof (gdk_screen_list_visuals) IA__gdk_screen_list_visuals __attribute((visibility("hidden")));
#define gdk_screen_list_visuals IA__gdk_screen_list_visuals

#endif
#endif
#if IN_HEADER(__GDK_SCREEN_H__)
#if IN_FILE(__GDK_WINDOW_C__)
extern __typeof (gdk_screen_get_toplevel_windows) IA__gdk_screen_get_toplevel_windows __attribute((visibility("hidden")));
#define gdk_screen_get_toplevel_windows IA__gdk_screen_get_toplevel_windows

#endif
#endif
#if IN_HEADER(__GDK_SCREEN_H__)
#if IN_FILE(__GDK_SCREEN_X11_C__)
extern __typeof (gdk_screen_get_display) IA__gdk_screen_get_display __attribute((visibility("hidden")));
#define gdk_screen_get_display IA__gdk_screen_get_display

extern __typeof (gdk_screen_get_width) IA__gdk_screen_get_width __attribute((visibility("hidden")));
#define gdk_screen_get_width IA__gdk_screen_get_width

extern __typeof (gdk_screen_get_width_mm) IA__gdk_screen_get_width_mm __attribute((visibility("hidden")));
#define gdk_screen_get_width_mm IA__gdk_screen_get_width_mm

extern __typeof (gdk_screen_get_height) IA__gdk_screen_get_height __attribute((visibility("hidden")));
#define gdk_screen_get_height IA__gdk_screen_get_height

extern __typeof (gdk_screen_get_height_mm) IA__gdk_screen_get_height_mm __attribute((visibility("hidden")));
#define gdk_screen_get_height_mm IA__gdk_screen_get_height_mm

extern __typeof (gdk_screen_get_number) IA__gdk_screen_get_number __attribute((visibility("hidden")));
#define gdk_screen_get_number IA__gdk_screen_get_number

extern __typeof (gdk_screen_get_primary_monitor) IA__gdk_screen_get_primary_monitor __attribute((visibility("hidden")));
#define gdk_screen_get_primary_monitor IA__gdk_screen_get_primary_monitor

extern __typeof (gdk_screen_get_root_window) IA__gdk_screen_get_root_window __attribute((visibility("hidden")));
#define gdk_screen_get_root_window IA__gdk_screen_get_root_window

extern __typeof (gdk_screen_get_default_colormap) IA__gdk_screen_get_default_colormap __attribute((visibility("hidden")));
#define gdk_screen_get_default_colormap IA__gdk_screen_get_default_colormap

extern __typeof (gdk_screen_set_default_colormap) IA__gdk_screen_set_default_colormap __attribute((visibility("hidden")));
#define gdk_screen_set_default_colormap IA__gdk_screen_set_default_colormap

extern __typeof (gdk_screen_get_n_monitors) IA__gdk_screen_get_n_monitors __attribute((visibility("hidden")));
#define gdk_screen_get_n_monitors IA__gdk_screen_get_n_monitors

extern __typeof (gdk_screen_get_monitor_geometry) IA__gdk_screen_get_monitor_geometry __attribute((visibility("hidden")));
#define gdk_screen_get_monitor_geometry IA__gdk_screen_get_monitor_geometry

extern __typeof (gdk_screen_get_monitor_width_mm) IA__gdk_screen_get_monitor_width_mm __attribute((visibility("hidden")));
#define gdk_screen_get_monitor_width_mm IA__gdk_screen_get_monitor_width_mm

extern __typeof (gdk_screen_get_monitor_height_mm) IA__gdk_screen_get_monitor_height_mm __attribute((visibility("hidden")));
#define gdk_screen_get_monitor_height_mm IA__gdk_screen_get_monitor_height_mm

extern __typeof (gdk_screen_get_monitor_plug_name) IA__gdk_screen_get_monitor_plug_name __attribute((visibility("hidden")));
#define gdk_screen_get_monitor_plug_name IA__gdk_screen_get_monitor_plug_name

extern __typeof (gdk_screen_get_rgba_colormap) IA__gdk_screen_get_rgba_colormap __attribute((visibility("hidden")));
#define gdk_screen_get_rgba_colormap IA__gdk_screen_get_rgba_colormap

extern __typeof (gdk_screen_get_rgba_visual) IA__gdk_screen_get_rgba_visual __attribute((visibility("hidden")));
#define gdk_screen_get_rgba_visual IA__gdk_screen_get_rgba_visual

extern __typeof (gdk_screen_get_active_window) IA__gdk_screen_get_active_window __attribute((visibility("hidden")));
#define gdk_screen_get_active_window IA__gdk_screen_get_active_window

extern __typeof (gdk_screen_get_window_stack) IA__gdk_screen_get_window_stack __attribute((visibility("hidden")));
#define gdk_screen_get_window_stack IA__gdk_screen_get_window_stack

extern __typeof (gdk_screen_is_composited) IA__gdk_screen_is_composited __attribute((visibility("hidden")));
#define gdk_screen_is_composited IA__gdk_screen_is_composited

extern __typeof (gdk_screen_make_display_name) IA__gdk_screen_make_display_name __attribute((visibility("hidden")));
#define gdk_screen_make_display_name IA__gdk_screen_make_display_name

#endif
#endif
#if IN_HEADER(__GDK_SCREEN_H__)
#if IN_FILE(__GDK_COLOR_X11_C__)
extern __typeof (gdk_screen_get_system_colormap) IA__gdk_screen_get_system_colormap __attribute((visibility("hidden")));
#define gdk_screen_get_system_colormap IA__gdk_screen_get_system_colormap

#endif
#endif
#if IN_HEADER(__GDK_SELECTION_H__)
#if IN_FILE(__GDK_SELECTION_C__)
extern __typeof (gdk_selection_owner_set) IA__gdk_selection_owner_set __attribute((visibility("hidden")));
#define gdk_selection_owner_set IA__gdk_selection_owner_set

extern __typeof (gdk_selection_owner_get) IA__gdk_selection_owner_get __attribute((visibility("hidden")));
#define gdk_selection_owner_get IA__gdk_selection_owner_get

extern __typeof (gdk_selection_send_notify) IA__gdk_selection_send_notify __attribute((visibility("hidden")));
#define gdk_selection_send_notify IA__gdk_selection_send_notify

#endif
#endif
#if IN_HEADER(__GDK_SELECTION_H__)
#if IN_FILE(__GDK_SELECTION_X11_C__)
extern __typeof (gdk_selection_convert) IA__gdk_selection_convert __attribute((visibility("hidden")));
#define gdk_selection_convert IA__gdk_selection_convert

extern __typeof (gdk_selection_owner_get_for_display) IA__gdk_selection_owner_get_for_display __attribute((visibility("hidden")));
#define gdk_selection_owner_get_for_display IA__gdk_selection_owner_get_for_display

extern __typeof (gdk_selection_owner_set_for_display) IA__gdk_selection_owner_set_for_display __attribute((visibility("hidden")));
#define gdk_selection_owner_set_for_display IA__gdk_selection_owner_set_for_display

extern __typeof (gdk_selection_property_get) IA__gdk_selection_property_get __attribute((visibility("hidden")));
#define gdk_selection_property_get IA__gdk_selection_property_get

extern __typeof (gdk_selection_send_notify_for_display) IA__gdk_selection_send_notify_for_display __attribute((visibility("hidden")));
#define gdk_selection_send_notify_for_display IA__gdk_selection_send_notify_for_display

#endif
#endif
#if IN_HEADER(__GDK_WINDOW_H__)
#if IN_FILE(__GDK_DISPLAY_C__)
extern __typeof (gdk_set_sm_client_id) IA__gdk_set_sm_client_id __attribute((visibility("hidden")));
#define gdk_set_sm_client_id IA__gdk_set_sm_client_id

#endif
#endif
#if IN_HEADER(__GDK_SPAWN_H__)
#if IN_FILE(__GDK_SPAWN_X11_C__)
#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_spawn_command_line_on_screen) IA__gdk_spawn_command_line_on_screen __attribute((visibility("hidden")));
#define gdk_spawn_command_line_on_screen IA__gdk_spawn_command_line_on_screen

extern __typeof (gdk_spawn_on_screen) IA__gdk_spawn_on_screen __attribute((visibility("hidden")));
#define gdk_spawn_on_screen IA__gdk_spawn_on_screen

extern __typeof (gdk_spawn_on_screen_with_pipes) IA__gdk_spawn_on_screen_with_pipes __attribute((visibility("hidden")));
#define gdk_spawn_on_screen_with_pipes IA__gdk_spawn_on_screen_with_pipes

#endif
#endif
#endif
#if IN_HEADER(__GDK_PRIVATE_H__)
#if IN_FILE(__GDK_EVENTS_C__)
extern __typeof (gdk_synthesize_window_state) IA__gdk_synthesize_window_state __attribute((visibility("hidden")));
#define gdk_synthesize_window_state IA__gdk_synthesize_window_state

#endif
#endif
#if IN_HEADER(__GDK_PRIVATE_H__)
#if IN_FILE(__GDK_WINDOW_X11_C__)
extern __typeof (gdk_window_destroy_notify) IA__gdk_window_destroy_notify __attribute((visibility("hidden")));
#define gdk_window_destroy_notify IA__gdk_window_destroy_notify

#endif
#endif
#ifdef GDK_WINDOWING_WIN32
#if IN_HEADER(__GDK_WIN32_H__)
#if IN_FILE(__GDK_WINDOW_WIN32_C__)
extern __typeof (gdk_win32_window_is_win32) IA__gdk_win32_window_is_win32 __attribute((visibility("hidden")));
#define gdk_win32_window_is_win32 IA__gdk_win32_window_is_win32

extern __typeof (gdk_win32_window_get_impl_hwnd) IA__gdk_win32_window_get_impl_hwnd __attribute((visibility("hidden")));
#define gdk_win32_window_get_impl_hwnd IA__gdk_win32_window_get_impl_hwnd

extern __typeof (gdk_win32_begin_direct_draw_libgtk_only) IA__gdk_win32_begin_direct_draw_libgtk_only __attribute((visibility("hidden")));
#define gdk_win32_begin_direct_draw_libgtk_only IA__gdk_win32_begin_direct_draw_libgtk_only

extern __typeof (gdk_win32_end_direct_draw_libgtk_only) IA__gdk_win32_end_direct_draw_libgtk_only __attribute((visibility("hidden")));
#define gdk_win32_end_direct_draw_libgtk_only IA__gdk_win32_end_direct_draw_libgtk_only

extern __typeof (gdk_win32_window_lookup_for_display) IA__gdk_win32_window_lookup_for_display __attribute((visibility("hidden")));
#define gdk_win32_window_lookup_for_display IA__gdk_win32_window_lookup_for_display

extern __typeof (gdk_win32_window_foreign_new_for_display) IA__gdk_win32_window_foreign_new_for_display __attribute((visibility("hidden")));
#define gdk_win32_window_foreign_new_for_display IA__gdk_win32_window_foreign_new_for_display

#endif
#endif
#if IN_HEADER(__GDK_WIN32_H__)
#if IN_FILE(__GDK_WIN32ID_C__)
extern __typeof (gdk_win32_handle_table_lookup) IA__gdk_win32_handle_table_lookup __attribute((visibility("hidden")));
#define gdk_win32_handle_table_lookup IA__gdk_win32_handle_table_lookup

#endif
#endif
#if IN_HEADER(__GDK_WIN32_H__)
#if IN_FILE(__GDK_CURSOR_WIN32_C__)
extern __typeof (gdk_win32_icon_to_pixbuf_libgtk_only) IA__gdk_win32_icon_to_pixbuf_libgtk_only __attribute((visibility("hidden")));
#define gdk_win32_icon_to_pixbuf_libgtk_only IA__gdk_win32_icon_to_pixbuf_libgtk_only

extern __typeof (gdk_win32_pixbuf_to_hicon_libgtk_only) IA__gdk_win32_pixbuf_to_hicon_libgtk_only __attribute((visibility("hidden")));
#define gdk_win32_pixbuf_to_hicon_libgtk_only IA__gdk_win32_pixbuf_to_hicon_libgtk_only

#endif
#endif
#if IN_HEADER(__GDK_WIN32_H__)
#if IN_FILE(__GDK_DRAWABLE_WIN32_C__)
extern __typeof (gdk_win32_drawable_get_handle) IA__gdk_win32_drawable_get_handle __attribute((visibility("hidden")));
#define gdk_win32_drawable_get_handle IA__gdk_win32_drawable_get_handle

#endif
#endif
#if IN_HEADER(__GDK_WIN32_H__)
#if IN_FILE(__GDK_EVENTS_WIN32_C__)
extern __typeof (gdk_win32_set_modal_dialog_libgtk_only) IA__gdk_win32_set_modal_dialog_libgtk_only __attribute((visibility("hidden")));
#define gdk_win32_set_modal_dialog_libgtk_only IA__gdk_win32_set_modal_dialog_libgtk_only

#endif
#endif
#if IN_HEADER(__GDK_WIN32_H__)
#if IN_FILE(__GDK_GC_WIN32_C__)
extern __typeof (gdk_win32_hdc_get) IA__gdk_win32_hdc_get __attribute((visibility("hidden")));
#define gdk_win32_hdc_get IA__gdk_win32_hdc_get

extern __typeof (gdk_win32_hdc_release) IA__gdk_win32_hdc_release __attribute((visibility("hidden")));
#define gdk_win32_hdc_release IA__gdk_win32_hdc_release

#endif
#endif
#if IN_HEADER(__GDK_WIN32_H__)
#if IN_FILE(__GDK_SELECTION_WIN32_C__)
extern __typeof (gdk_win32_selection_add_targets) IA__gdk_win32_selection_add_targets __attribute((visibility("hidden")));
#define gdk_win32_selection_add_targets IA__gdk_win32_selection_add_targets

#endif
#endif
#if IN_HEADER(__GDK_WIN32_H__)
#if IN_FILE(__GDK_KEYS_WIN32_C__)
extern __typeof (gdk_win32_keymap_get_type) IA__gdk_win32_keymap_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_win32_keymap_get_type IA__gdk_win32_keymap_get_type

extern __typeof (gdk_win32_keymap_check_compose) IA__gdk_win32_keymap_check_compose __attribute((visibility("hidden")));
#define gdk_win32_keymap_check_compose IA__gdk_win32_keymap_check_compose

#endif
#endif
#endif
#ifdef GDK_WINDOWING_X11
#if IN_HEADER(__GDK_X_H__)
#if IN_FILE(__GDK_PROPERTY_X11_C__)
extern __typeof (gdk_x11_atom_to_xatom) IA__gdk_x11_atom_to_xatom __attribute((visibility("hidden")));
#define gdk_x11_atom_to_xatom IA__gdk_x11_atom_to_xatom

extern __typeof (gdk_x11_atom_to_xatom_for_display) IA__gdk_x11_atom_to_xatom_for_display __attribute((visibility("hidden")));
#define gdk_x11_atom_to_xatom_for_display IA__gdk_x11_atom_to_xatom_for_display

extern __typeof (gdk_x11_get_xatom_by_name) IA__gdk_x11_get_xatom_by_name __attribute((visibility("hidden")));
#define gdk_x11_get_xatom_by_name IA__gdk_x11_get_xatom_by_name

extern __typeof (gdk_x11_get_xatom_by_name_for_display) IA__gdk_x11_get_xatom_by_name_for_display __attribute((visibility("hidden")));
#define gdk_x11_get_xatom_by_name_for_display IA__gdk_x11_get_xatom_by_name_for_display

extern __typeof (gdk_x11_get_xatom_name) IA__gdk_x11_get_xatom_name __attribute((visibility("hidden")));
#define gdk_x11_get_xatom_name IA__gdk_x11_get_xatom_name

extern __typeof (gdk_x11_get_xatom_name_for_display) IA__gdk_x11_get_xatom_name_for_display __attribute((visibility("hidden")));
#define gdk_x11_get_xatom_name_for_display IA__gdk_x11_get_xatom_name_for_display

extern __typeof (gdk_x11_xatom_to_atom) IA__gdk_x11_xatom_to_atom __attribute((visibility("hidden")));
#define gdk_x11_xatom_to_atom IA__gdk_x11_xatom_to_atom

extern __typeof (gdk_x11_xatom_to_atom_for_display) IA__gdk_x11_xatom_to_atom_for_display __attribute((visibility("hidden")));
#define gdk_x11_xatom_to_atom_for_display IA__gdk_x11_xatom_to_atom_for_display

#endif
#if IN_FILE(__GDK_COLOR_X11_C__)
extern __typeof (gdk_x11_colormap_foreign_new) IA__gdk_x11_colormap_foreign_new __attribute((visibility("hidden")));
#define gdk_x11_colormap_foreign_new IA__gdk_x11_colormap_foreign_new

extern __typeof (gdk_x11_colormap_get_xcolormap) IA__gdk_x11_colormap_get_xcolormap __attribute((visibility("hidden")));
#define gdk_x11_colormap_get_xcolormap IA__gdk_x11_colormap_get_xcolormap

extern __typeof (gdk_x11_colormap_get_xdisplay) IA__gdk_x11_colormap_get_xdisplay __attribute((visibility("hidden")));
#define gdk_x11_colormap_get_xdisplay IA__gdk_x11_colormap_get_xdisplay

#ifdef GDK_ENABLE_BROKEN
extern __typeof (gdkx_colormap_get) IA__gdkx_colormap_get __attribute((visibility("hidden")));
#define gdkx_colormap_get IA__gdkx_colormap_get

#endif
#endif
#if IN_FILE(__GDK_CURSOR_X11_C__)
extern __typeof (gdk_x11_cursor_get_xcursor) IA__gdk_x11_cursor_get_xcursor __attribute((visibility("hidden")));
#define gdk_x11_cursor_get_xcursor IA__gdk_x11_cursor_get_xcursor

extern __typeof (gdk_x11_cursor_get_xdisplay) IA__gdk_x11_cursor_get_xdisplay __attribute((visibility("hidden")));
#define gdk_x11_cursor_get_xdisplay IA__gdk_x11_cursor_get_xdisplay

extern __typeof (gdk_x11_display_set_cursor_theme) IA__gdk_x11_display_set_cursor_theme __attribute((visibility("hidden")));
#define gdk_x11_display_set_cursor_theme IA__gdk_x11_display_set_cursor_theme

#endif
#if IN_FILE(__GDK_DISPLAY_X11_C__)
extern __typeof (gdk_x11_display_get_user_time) IA__gdk_x11_display_get_user_time __attribute((visibility("hidden")));
#define gdk_x11_display_get_user_time IA__gdk_x11_display_get_user_time

extern __typeof (gdk_x11_display_get_xdisplay) IA__gdk_x11_display_get_xdisplay __attribute((visibility("hidden")));
#define gdk_x11_display_get_xdisplay IA__gdk_x11_display_get_xdisplay

extern __typeof (gdk_x11_display_grab) IA__gdk_x11_display_grab __attribute((visibility("hidden")));
#define gdk_x11_display_grab IA__gdk_x11_display_grab

extern __typeof (gdk_x11_display_ungrab) IA__gdk_x11_display_ungrab __attribute((visibility("hidden")));
#define gdk_x11_display_ungrab IA__gdk_x11_display_ungrab

extern __typeof (gdk_x11_lookup_xdisplay) IA__gdk_x11_lookup_xdisplay __attribute((visibility("hidden")));
#define gdk_x11_lookup_xdisplay IA__gdk_x11_lookup_xdisplay

extern __typeof (gdk_x11_display_broadcast_startup_message) IA__gdk_x11_display_broadcast_startup_message __attribute((visibility("hidden")));
#define gdk_x11_display_broadcast_startup_message IA__gdk_x11_display_broadcast_startup_message

extern __typeof (gdk_x11_display_get_startup_notification_id) IA__gdk_x11_display_get_startup_notification_id __attribute((visibility("hidden")));
#define gdk_x11_display_get_startup_notification_id IA__gdk_x11_display_get_startup_notification_id

#endif
#if IN_FILE(__GDK_DRAWABLE_X11_C__)
extern __typeof (gdk_x11_drawable_get_xdisplay) IA__gdk_x11_drawable_get_xdisplay __attribute((visibility("hidden")));
#define gdk_x11_drawable_get_xdisplay IA__gdk_x11_drawable_get_xdisplay

extern __typeof (gdk_x11_drawable_get_xid) IA__gdk_x11_drawable_get_xid __attribute((visibility("hidden")));
#define gdk_x11_drawable_get_xid IA__gdk_x11_drawable_get_xid

extern __typeof (gdk_x11_window_get_drawable_impl) IA__gdk_x11_window_get_drawable_impl __attribute((visibility("hidden")));
#define gdk_x11_window_get_drawable_impl IA__gdk_x11_window_get_drawable_impl

extern __typeof (gdk_x11_pixmap_get_drawable_impl) IA__gdk_x11_pixmap_get_drawable_impl __attribute((visibility("hidden")));
#define gdk_x11_pixmap_get_drawable_impl IA__gdk_x11_pixmap_get_drawable_impl

#endif
#if IN_FILE(__GDK_FONT_X11_C__)
#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdk_x11_font_get_name) IA__gdk_x11_font_get_name __attribute((visibility("hidden")));
#define gdk_x11_font_get_name IA__gdk_x11_font_get_name

extern __typeof (gdk_x11_font_get_xdisplay) IA__gdk_x11_font_get_xdisplay __attribute((visibility("hidden")));
#define gdk_x11_font_get_xdisplay IA__gdk_x11_font_get_xdisplay

#endif
extern __typeof (gdk_x11_font_get_xfont) IA__gdk_x11_font_get_xfont __attribute((visibility("hidden")));
#define gdk_x11_font_get_xfont IA__gdk_x11_font_get_xfont

#endif
#if IN_FILE(__GDK_GC_X11_C__)
extern __typeof (gdk_x11_gc_get_xdisplay) IA__gdk_x11_gc_get_xdisplay __attribute((visibility("hidden")));
#define gdk_x11_gc_get_xdisplay IA__gdk_x11_gc_get_xdisplay

extern __typeof (gdk_x11_gc_get_xgc) IA__gdk_x11_gc_get_xgc __attribute((visibility("hidden")));
#define gdk_x11_gc_get_xgc IA__gdk_x11_gc_get_xgc

#endif
#if IN_FILE(__GDK_MAIN_X11_C__)
extern __typeof (gdk_x11_get_default_root_xwindow) IA__gdk_x11_get_default_root_xwindow __attribute((visibility("hidden")));
#define gdk_x11_get_default_root_xwindow IA__gdk_x11_get_default_root_xwindow

extern __typeof (gdk_x11_get_default_screen) IA__gdk_x11_get_default_screen __attribute((visibility("hidden")));
#define gdk_x11_get_default_screen IA__gdk_x11_get_default_screen

extern __typeof (gdk_x11_get_default_xdisplay) IA__gdk_x11_get_default_xdisplay __attribute((visibility("hidden")));
#define gdk_x11_get_default_xdisplay IA__gdk_x11_get_default_xdisplay

extern __typeof (gdk_x11_grab_server) IA__gdk_x11_grab_server __attribute((visibility("hidden")));
#define gdk_x11_grab_server IA__gdk_x11_grab_server

extern __typeof (gdk_x11_ungrab_server) IA__gdk_x11_ungrab_server __attribute((visibility("hidden")));
#define gdk_x11_ungrab_server IA__gdk_x11_ungrab_server

extern __typeof (gdk_x11_set_sm_client_id) IA__gdk_x11_set_sm_client_id __attribute((visibility("hidden")));
#define gdk_x11_set_sm_client_id IA__gdk_x11_set_sm_client_id

#endif
#if IN_FILE(__GDK_EVENTS_X11_C__)
extern __typeof (gdk_x11_get_server_time) IA__gdk_x11_get_server_time __attribute((visibility("hidden")));
#define gdk_x11_get_server_time IA__gdk_x11_get_server_time

extern __typeof (gdk_x11_register_standard_event_type) IA__gdk_x11_register_standard_event_type __attribute((visibility("hidden")));
#define gdk_x11_register_standard_event_type IA__gdk_x11_register_standard_event_type

extern __typeof (gdk_x11_screen_get_window_manager_name) IA__gdk_x11_screen_get_window_manager_name __attribute((visibility("hidden")));
#define gdk_x11_screen_get_window_manager_name IA__gdk_x11_screen_get_window_manager_name

extern __typeof (gdk_x11_screen_supports_net_wm_hint) IA__gdk_x11_screen_supports_net_wm_hint __attribute((visibility("hidden")));
#define gdk_x11_screen_supports_net_wm_hint IA__gdk_x11_screen_supports_net_wm_hint

#endif
#if IN_FILE(__GDK_IMAGE_X11_C__)
extern __typeof (gdk_x11_image_get_xdisplay) IA__gdk_x11_image_get_xdisplay __attribute((visibility("hidden")));
#define gdk_x11_image_get_xdisplay IA__gdk_x11_image_get_xdisplay

extern __typeof (gdk_x11_image_get_ximage) IA__gdk_x11_image_get_ximage __attribute((visibility("hidden")));
#define gdk_x11_image_get_ximage IA__gdk_x11_image_get_ximage

#endif
#if IN_FILE(__GDK_SCREEN_X11_C__)
extern __typeof (gdk_x11_screen_get_screen_number) IA__gdk_x11_screen_get_screen_number __attribute((visibility("hidden")));
#define gdk_x11_screen_get_screen_number IA__gdk_x11_screen_get_screen_number

extern __typeof (gdk_x11_screen_get_xscreen) IA__gdk_x11_screen_get_xscreen __attribute((visibility("hidden")));
#define gdk_x11_screen_get_xscreen IA__gdk_x11_screen_get_xscreen

extern __typeof (gdk_x11_screen_get_monitor_output) IA__gdk_x11_screen_get_monitor_output __attribute((visibility("hidden")));
#define gdk_x11_screen_get_monitor_output IA__gdk_x11_screen_get_monitor_output

#endif
#if IN_FILE(__GDK_VISUAL_X11_C__)
extern __typeof (gdk_x11_screen_lookup_visual) IA__gdk_x11_screen_lookup_visual __attribute((visibility("hidden")));
#define gdk_x11_screen_lookup_visual IA__gdk_x11_screen_lookup_visual

extern __typeof (gdk_x11_visual_get_xvisual) IA__gdk_x11_visual_get_xvisual __attribute((visibility("hidden")));
#define gdk_x11_visual_get_xvisual IA__gdk_x11_visual_get_xvisual

#ifndef GDK_DISABLE_DEPRECATED
extern __typeof (gdkx_visual_get) IA__gdkx_visual_get __attribute((visibility("hidden")));
#define gdkx_visual_get IA__gdkx_visual_get

#endif
#endif
#if IN_FILE(__GDK_WINDOW_X11_C__)
extern __typeof (gdk_x11_window_set_user_time) IA__gdk_x11_window_set_user_time __attribute((visibility("hidden")));
#define gdk_x11_window_set_user_time IA__gdk_x11_window_set_user_time

extern __typeof (gdk_x11_window_move_to_current_desktop) IA__gdk_x11_window_move_to_current_desktop __attribute((visibility("hidden")));
#define gdk_x11_window_move_to_current_desktop IA__gdk_x11_window_move_to_current_desktop

extern __typeof (gdk_x11_window_foreign_new_for_display) IA__gdk_x11_window_foreign_new_for_display __attribute((visibility("hidden")));
#define gdk_x11_window_foreign_new_for_display IA__gdk_x11_window_foreign_new_for_display

extern __typeof (gdk_x11_window_lookup_for_display) IA__gdk_x11_window_lookup_for_display __attribute((visibility("hidden")));
#define gdk_x11_window_lookup_for_display IA__gdk_x11_window_lookup_for_display

#endif
#if IN_FILE(__GDK_XID_C__)
extern __typeof (gdk_xid_table_lookup) IA__gdk_xid_table_lookup __attribute((visibility("hidden")));
#define gdk_xid_table_lookup IA__gdk_xid_table_lookup

extern __typeof (gdk_xid_table_lookup_for_display) IA__gdk_xid_table_lookup_for_display __attribute((visibility("hidden")));
#define gdk_xid_table_lookup_for_display IA__gdk_xid_table_lookup_for_display

#endif
#endif
#endif
#if IN_HEADER(__GDK_APP_LAUNCH_CONTEXT_H__)
#if IN_FILE(__GDK_APP_LAUNCH_CONTEXT_C__)
extern __typeof (gdk_app_launch_context_get_type) IA__gdk_app_launch_context_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_app_launch_context_get_type IA__gdk_app_launch_context_get_type

extern __typeof (gdk_app_launch_context_new) IA__gdk_app_launch_context_new __attribute((visibility("hidden")));
#define gdk_app_launch_context_new IA__gdk_app_launch_context_new

extern __typeof (gdk_app_launch_context_set_display) IA__gdk_app_launch_context_set_display __attribute((visibility("hidden")));
#define gdk_app_launch_context_set_display IA__gdk_app_launch_context_set_display

extern __typeof (gdk_app_launch_context_set_screen) IA__gdk_app_launch_context_set_screen __attribute((visibility("hidden")));
#define gdk_app_launch_context_set_screen IA__gdk_app_launch_context_set_screen

extern __typeof (gdk_app_launch_context_set_desktop) IA__gdk_app_launch_context_set_desktop __attribute((visibility("hidden")));
#define gdk_app_launch_context_set_desktop IA__gdk_app_launch_context_set_desktop

extern __typeof (gdk_app_launch_context_set_timestamp) IA__gdk_app_launch_context_set_timestamp __attribute((visibility("hidden")));
#define gdk_app_launch_context_set_timestamp IA__gdk_app_launch_context_set_timestamp

extern __typeof (gdk_app_launch_context_set_icon) IA__gdk_app_launch_context_set_icon __attribute((visibility("hidden")));
#define gdk_app_launch_context_set_icon IA__gdk_app_launch_context_set_icon

extern __typeof (gdk_app_launch_context_set_icon_name) IA__gdk_app_launch_context_set_icon_name __attribute((visibility("hidden")));
#define gdk_app_launch_context_set_icon_name IA__gdk_app_launch_context_set_icon_name

#endif
#endif
#if IN_HEADER(__GDK_WINDOW_IMPL_H__)
#if IN_FILE(__GDK_WINDOW_IMPL_C__)
extern __typeof (gdk_window_impl_get_type) IA__gdk_window_impl_get_type __attribute((visibility("hidden"))) G_GNUC_CONST;
#define gdk_window_impl_get_type IA__gdk_window_impl_get_type

#endif
#endif
#ifdef GDK_WINDOWING_X11
#endif

#endif /* G_HAVE_GNUC_VISIBILITY */
#endif /* DISABLE_VISIBILITY */
